@@ -31,6 +31,7 @@
 #include "GormPrivate.h"
 #include "GormCustomView.h"
 #include "GormDocument.h"
+#include "GormFunctions.h"
 
 static Class gmodel_class(NSString *className);
 
@@ -38,6 +39,23 @@ static id gormNibOwner;
 static id gormRealObject;
 static BOOL gormFileOwnerDecoded;
 
+@interface NSWindow (GormPrivate)
+- (void) gmSetStyleMask: (unsigned int)mask;
+@end
+
+@implementation NSWindow (GormPrivate)
+// private method to change the Window style mask on the fly
+- (void) gmSetStyleMask: (unsigned int)mask
+{
+   _styleMask = mask;
+   [GSServerForWindow(self) stylewindow: mask : [self windowNumber]];
+}
+@end
+
+@interface NSWindow (GormNSWindowPrivate)
+- (unsigned int) _styleMask;
+@end
+
 @interface GModelApplication : NSObject
 {
   id mainMenu;
@@ -56,19 +74,6 @@ static BOOL gormFileOwnerDecoded;
 
 @end
 
-@interface NSWindow (GormPrivate)
-- (void) gmSetStyleMask: (unsigned int)mask;
-@end
-
-@implementation NSWindow (GormPrivate)
-// private method to change the Window style mask on the fly
-- (void) gmSetStyleMask: (unsigned int)mask
-{
-   _styleMask = mask;
-   [GSServerForWindow(self) stylewindow: mask : [self windowNumber]];
-}
-@end
-
 @implementation GModelApplication
 
 - (id)initWithModelUnarchiver:(GMUnarchiver*)unarchiver
@@ -88,6 +93,9 @@ static BOOL gormFileOwnerDecoded;
 	  NSLog(@"Fixing borderless window %@", win);
 	  [win gmSetStyleMask: NSTitledWindowMask];
 	}
+
+      /* Fix up the background color */
+      [win setBackgroundColor: [NSColor windowBackgroundColor]];
     }
 
   delegate = [unarchiver decodeObjectWithName:@"delegate"];
@@ -122,8 +130,32 @@ static BOOL gormFileOwnerDecoded;
 
 @end
 
-@implementation GormObjectProxy (GModel)
+@interface GModelMenuTemplate : NSObject
+{
+  NSString *menuClassName;
+  id realObject;
+}
 
++ (id)createObjectForModelUnarchiver:(GMUnarchiver*)unarchiver;
+- (id)initWithModelUnarchiver:(GMUnarchiver*)unarchiver;
+@end
+
+@implementation GModelMenuTemplate
+- (id)initWithModelUnarchiver:(GMUnarchiver*)unarchiver
+{
+  menuClassName = [unarchiver decodeObjectWithName:@"menuClassName"];
+  realObject = [unarchiver decodeObjectWithName: @"realObject"];
+  // RELEASE(self);
+  return realObject;
+}
+
++ (id)createObjectForModelUnarchiver:(GMUnarchiver*)unarchiver
+{
+  return AUTORELEASE([[GModelMenuTemplate alloc] init]);
+}
+@end
+
+@implementation GormObjectProxy (GModel)
 + (id)createObjectForModelUnarchiver:(GMUnarchiver*)unarchiver
 {
   return AUTORELEASE([[self alloc] init]);
@@ -139,8 +171,8 @@ static BOOL gormFileOwnerDecoded;
   realObject = [unarchiver decodeObjectWithName: @"realObject"];
 
   //real = [unarchiver representationForName: @"realObject" isLabeled: &label];
-
-  if (!gormFileOwnerDecoded) 
+  if (!gormFileOwnerDecoded || 
+      [realObject isKindOfClass: [GModelApplication class]]) 
     {
       gormFileOwnerDecoded = YES;
       gormNibOwner = self;
@@ -148,12 +180,10 @@ static BOOL gormFileOwnerDecoded;
     }  
   return self;
 }
-
 @end
 
 
 @implementation GormCustomView (GModel)
-
 + (id)createObjectForModelUnarchiver:(GMUnarchiver*)unarchiver
 {
   return AUTORELEASE([[self alloc] initWithFrame: NSMakeRect(0,0,10,10)]);
@@ -180,10 +210,8 @@ static BOOL gormFileOwnerDecoded;
   
   return self;
 }
-
 @end
 
-
 @implementation GormDocument (GModel)
 
 /* Try to define a possibly custom class that's in the gmodel
@@ -192,20 +220,20 @@ static BOOL gormFileOwnerDecoded;
    is, and at best, we could search the connections to see what
    outlets and actions are used.
 */
-- (void) defineClass: (id)object inFile: (NSString *)path
+- (void) defineClass: (id)className inFile: (NSString *)path
 {
-  NSString *classname = [object className];
   int result;
   NSString *header;
   NSFileManager *mgr;
+  NSRange notFound = NSMakeRange(NSNotFound, 0);
 
-  if ([classManager isKnownClass: classname])
+  if ([classManager isKnownClass: className])
     return;
   
   /* Can we parse a header in this directory? */
   mgr = [NSFileManager defaultManager];
   path = [path stringByDeletingLastPathComponent];
-  header = [path stringByAppendingPathComponent: classname];
+  header = [path stringByAppendingPathComponent: className];
   header = [header stringByAppendingPathExtension: @"h"];
   if ([mgr fileExistsAtPath: header])
     {
@@ -213,15 +241,15 @@ static BOOL gormFileOwnerDecoded;
 	NSRunAlertPanel(_(@"GModel Loading"),
 			_(@"Parse %@ to define unknown class %@?"),
 			_(@"Yes"), _(@"No"), _(@"Choose File"),
-			header, classname, nil);
+			header, className, nil);
     }
   else
     {
       result = 
 	NSRunAlertPanel(_(@"GModel Loading"),
 			_(@"Unknown class %@. Parse header file to define?"),
-			_(@"Yes"), _(@"No"), nil,
-			classname, nil);
+			_(@"Yes"), _(@"No, Choose Superclass"), nil,
+			className, nil);
       if (result == NSAlertDefaultReturn)
 	result = NSAlertOtherReturn;
     }
@@ -242,20 +270,33 @@ static BOOL gormFileOwnerDecoded;
   // make a guess and warn the user
   if (result != NSAlertDefaultReturn)
     {
-      NSString *superClass = nil;
+      NSString *superClass = promptForClassName([NSString stringWithFormat: @"Superclass: %@",className],
+						[classManager allClassNames]);
       BOOL added = NO;
-
-      if(superClass == nil && 
-	 [object isKindOfClass: [GormCustomView class]])
+      
+      // RETAIN(superClass);
+      // cheesy attempt to determine superclass..
+      if(superClass == nil)
 	{
-	  superClass = @"NSView";
-	}
-      else
-	{
-	  superClass = @"NSObject";
+	  if([className isEqual: @"GormCustomView"])
+	    {
+	      superClass = @"NSView";
+	    }
+	  else if(NSEqualRanges(notFound,[className rangeOfString: @"Window"]) == NO)
+	    {
+	      superClass = @"NSWindow"; 
+	    }
+	  else if(NSEqualRanges(notFound,[className rangeOfString: @"Panel"]) == NO)
+	    {
+	      superClass = @"NSPanel";
+	    }
+	  else
+	    {
+	      superClass = @"NSObject";
+	    }
 	}
 
-      added = [classManager addClassNamed: classname
+      added = [classManager addClassNamed: className
 			    withSuperClassNamed: superClass
 			    withActions: [NSMutableArray array]
 			    withOutlets: [NSMutableArray array]];
@@ -263,16 +304,35 @@ static BOOL gormFileOwnerDecoded;
       // inform the user...
       if(added)
 	{
-	  NSLog(@"Added class %@ with superclass of %@.", classname, superClass);
+	  NSLog(@"Added class %@ with superclass of %@.", className, superClass);
 	}
       else
 	{
-	  NSLog(@"Failed to add class %@ with superclass of %@.", classname, superClass);
+	  NSLog(@"Failed to add class %@ with superclass of %@.", className, superClass);
 	}
     }
   else
     {
-      [classManager parseHeader: header];
+      NS_DURING
+	{
+	  if(![classManager parseHeader: header])
+	    {
+	      NSString *file = [header lastPathComponent];
+	      NSString *message = [NSString stringWithFormat: 
+					      _(@"Unable to parse class in %@"),file];
+	      NSRunAlertPanel(_(@"Problem parsing class"), 
+			      message,
+			      nil, nil, nil);
+	    }
+	}
+      NS_HANDLER
+	{
+	  NSString *message = [localException reason];
+	  NSRunAlertPanel(_(@"Problem parsing class"), 
+			  message,
+			  nil, nil, nil);
+	}
+      NS_ENDHANDLER;
     }
 }
 
@@ -289,6 +349,63 @@ static BOOL gormFileOwnerDecoded;
   return object;
 }
 
+- (NSDictionary *) processModel: (NSMutableDictionary *)model
+			 inPath: (NSString *)path
+{
+  NSMutableDictionary *customMap = nil;
+  NSEnumerator *en = [model objectEnumerator];
+  id obj;
+
+  NSLog(@"Processing model...");
+  while((obj = [en nextObject]) != nil)
+    {
+      if([obj isKindOfClass: [NSDictionary class]])
+	{
+	  NSString *objIsa = [(NSMutableDictionary *)obj objectForKey: @"isa"];
+	  Class cls = NSClassFromString(objIsa);
+	  
+	  // NSLog(@"isa = %@",objIsa);
+	  if([classManager isKnownClass: objIsa] == NO &&
+	     [objIsa isEqual: @"IMControlConnector"] == NO &&
+	     [objIsa isEqual: @"IMOutletConnector"] == NO &&
+	     [objIsa isEqual: @"IMCustomObject"] == NO &&
+	     [objIsa isEqual: @"IMCustomView"] == NO &&
+	     cls == nil)
+	    {
+	      NSString *superClass;
+	      
+	      NSLog(@"%@ is not a known class",objIsa);
+	      [self defineClass: objIsa inFile: path];
+	      superClass = [classManager superClassNameForClassNamed: objIsa];
+	      [(NSMutableDictionary *)obj setObject: superClass forKey: @"isa"];
+
+	      // guess at name which will be given in the nameTable...
+	      /*
+	      if([superClass isEqual: @"NSMenu"])
+		name = @"GormNSMenu";
+	      else if([superClass isEqual: @"NSWindow"])
+		name = @"GormNSWindow";
+	      else if([superClass isEqual: @"NSPanel"])
+		name = @"GormNSPanel";
+	      else if([superClass isEqual: @"NSBrowser"])
+		name = @"GormNSBrowser";
+	      else if([superClass isEqual: @"NSTableView"])
+		name = @"GormNSTableView";
+	      else if([superClass isEqual: @"NSOutlineView"])
+		name = @"GormNSOutlineView";
+	      else if([superClass isEqual: @"NSPopUpButton"])
+		name = @"GormNSPopUpButton";
+	      else if([superClass isEqual: @"NSPopUpButtonCell"]) 
+		name = @"GormNSPopUpButtonCell";
+	      else if([superClass isEqual: @"NSOutlineView"])
+		name = @"GormNSOutlineView";
+	      */
+	    }
+	}
+    }
+  
+  return customMap;
+}
 
 /* importing of legacy gmodel files.*/
 - (id) openGModel: (NSString *)path
@@ -301,27 +418,35 @@ static BOOL gormFileOwnerDecoded;
   NSArray          *gmconnections;
   Class             u = gmodel_class(@"GMUnarchiver");
   NSString         *delegateClass = nil;
+  NSMutableDictionary *model;
 
   NSLog (@"Loading gmodel file %@...", path);
   gormNibOwner = nil;
   gormRealObject = nil;
   gormFileOwnerDecoded = NO;
   /* GModel classes */
-  [u decodeClassName: @"NSApplication"   asClassName: @"GModelApplication"];
-  [u decodeClassName: @"IMCustomView"    asClassName: @"GormCustomView"];
-  [u decodeClassName: @"IMCustomObject"  asClassName: @"GormObjectProxy"];
+  [u decodeClassName: @"NSApplication"     asClassName: @"GModelApplication"];
+  [u decodeClassName: @"IMCustomView"      asClassName: @"GormCustomView"];
+  [u decodeClassName: @"IMCustomObject"    asClassName: @"GormObjectProxy"];
   /* Gorm classes */
-  [u decodeClassName: @"NSMenu"          asClassName: @"GormNSMenu"];
-  [u decodeClassName: @"NSWindow"        asClassName: @"GormNSWindow"];
-  [u decodeClassName: @"NSPanel"         asClassName: @"GormNSPanel"];
-  [u decodeClassName: @"NSBrowser"       asClassName: @"GormNSBrowser"];
-  [u decodeClassName: @"NSTableView"     asClassName: @"GormNSTableView"];
-  [u decodeClassName: @"NSOutlineView"   asClassName: @"GormNSOutlineView"];
-  [u decodeClassName: @"NSPopUpButton"   asClassName: @"GormNSPopUpButton"];
+  [u decodeClassName: @"NSMenu"            asClassName: @"GormNSMenu"];
+  [u decodeClassName: @"NSWindow"          asClassName: @"GormNSWindow"];
+  [u decodeClassName: @"NSPanel"           asClassName: @"GormNSPanel"];
+  [u decodeClassName: @"NSBrowser"         asClassName: @"GormNSBrowser"];
+  [u decodeClassName: @"NSTableView"       asClassName: @"GormNSTableView"];
+  [u decodeClassName: @"NSOutlineView"     asClassName: @"GormNSOutlineView"];
+  [u decodeClassName: @"NSPopUpButton"     asClassName: @"GormNSPopUpButton"];
   [u decodeClassName: @"NSPopUpButtonCell" asClassName: @"GormNSPopUpButtonCell"];
-  [u decodeClassName: @"NSOutlineView"   asClassName: @"GormNSOutlineView"];
+  [u decodeClassName: @"NSOutlineView"     asClassName: @"GormNSOutlineView"];
+  [u decodeClassName: @"NSMenuTemplate"    asClassName: @"GModelMenuTemplate"];
+  [u decodeClassName: @"NSCStringText"     asClassName: @"NSText"];
 
-  unarchiver = RETAIN([u unarchiverWithContentsOfFile: path]);
+  // process the model to take care of any custom classes...
+  model = [NSMutableDictionary dictionaryWithContentsOfFile: path];
+  [self processModel: model inPath: path];
+  
+  // initialize with the property list...
+  unarchiver = [[u alloc] initForReadingWithPropertyList: [[model description] propertyList]];
   if (!unarchiver)
     {
       NSLog(@"Failed to load gmodel file %@!!",path);
@@ -344,7 +469,7 @@ static BOOL gormFileOwnerDecoded;
 
   if (gormNibOwner)
     {
-      [self defineClass: gormNibOwner inFile: path];
+      [self defineClass: [gormNibOwner className] inFile: path];
       [filesOwner setClassName: [gormNibOwner className]];
     }
 
@@ -356,12 +481,25 @@ static BOOL gormFileOwnerDecoded;
   while ((obj = [enumerator nextObject]))
     {
       if (obj != gormNibOwner)
-	[self setName: nil forObject: obj];
+	{
+	  [self attachObject: obj toParent: nil];
+	}
 
       if([obj isKindOfClass: [GormObjectProxy class]])
 	{
-	  NSLog(@"processing... %@",[obj className]);
-	  [self defineClass: obj inFile: path];
+	  if([[obj className] isEqual: @"NSFontManager"])
+	    {
+	      // if it's the font manager, take care of it...
+	      [self setName: @"NSFont" forObject: obj];
+	      [self attachObject: obj toParent: nil];
+	      // RELEASE(item);    
+	      fontManager = obj;
+	    }
+	  else 
+	    {
+	      NSLog(@"processing... %@",[obj className]);
+	      [self defineClass: [obj className] inFile: path];
+	    }
 	} 
     }
 
@@ -430,25 +568,50 @@ static BOOL gormFileOwnerDecoded;
 
   if ([gormRealObject isKindOfClass: [GModelApplication class]])
     {
-      enumerator = [[gormRealObject windows] objectEnumerator];
-      while ((obj = [enumerator nextObject]))
+      if([gormRealObject respondsToSelector: @selector(windows)])
 	{
-	  if ([self nameForObject: obj] == nil)
-	    [self setName: nil forObject: obj];
-	}
-      if ([gormRealObject mainMenu])
-	{
-	  [self setName: @"NSMenu" forObject: [gormRealObject mainMenu]];
+	  enumerator = [[gormRealObject windows] objectEnumerator];
+	  while ((obj = [enumerator nextObject]))
+	    {
+	      if([obj isKindOfClass: [NSWindow class]])
+		{
+		  if([obj _styleMask] == 0)
+		    {
+		      // Skip borderless window.  Borderless windows are 
+		      // sometimes used as temporary objects in nib files, 
+		      // they will show up unless eliminated.
+		      continue; 
+		    }
+		}
+	      
+	      [self attachObject: obj toParent: nil];
+	    }
+	  
+	  if([gormRealObject respondsToSelector: @selector(mainMenu)])
+	    {
+	      if ([(GModelApplication *)gormRealObject mainMenu])
+		{
+		  [self attachObject: [(GModelApplication *)gormRealObject mainMenu] toParent: nil];
+		}
+	    }
 	}
+      
+    }
+  else if(gormRealObject != nil)
+    {
+      // Here we need to addClass:... (outlets, actions).  */
+      [self defineClass: [gormRealObject className] inFile: path];
     }
   else
     {
-      /* Here we need to addClass:... (outlets, actions).  */
-      //[self defineClass: [gormRealObject className] inFile: path];
       NSLog(@"Don't understand real object %@", gormRealObject);
     }
-  
+
   [self rebuildObjToNameMapping];
+
+  // RELEASE(unarchiver);
+  [self touch]; // mark the document
+
   return self;
 }
 @end
