@@ -34,7 +34,6 @@
 #include <AppKit/NSControl.h>
 #include <AppKit/NSButton.h>
 
-NSString *GormLinkPboardType = @"GormLinkPboardType";
 NSString *GormToggleGuidelineNotification = @"GormToggleGuidelineNotification";
 NSString *GormDidModifyClassNotification = @"GormDidModifyClassNotification";
 NSString *GormDidAddClassNotification = @"GormDidAddClassNotification";
@@ -45,6 +44,9 @@ NSString *GormResizeCellNotification = @"GormResizeCellNotification";
 // Define this as "NO" initially.   We only want to turn this on while loading or testing.
 static BOOL _isInInterfaceBuilder = NO;
 
+// Has poseAs: been called?
+static BOOL _illegalClassSubstitution = NO;
+
 static NSImage *gormImage = nil;
 static NSImage *testingImage = nil;
 
@@ -101,6 +103,24 @@ static NSImage *testingImage = nil;
 }
 @end
 
+@interface NSObject (GormPrivate)
++ (void) poseAsClass: (Class)aClassObject;
+@end
+
+@implementation NSObject (GormPrivate)
++ (void) poseAsClass: (Class)aClassObject
+{
+  BOOL allow = [[NSUserDefaults standardUserDefaults] boolForKey: @"AllowUserBundles"];
+
+  // disable poseAs: while in Gorm.
+  class_pose_as(self, aClassObject);
+  if(!allow)
+    {
+      _illegalClassSubstitution = YES;
+    }
+}
+@end
+
 @implementation GormObjectProxy
 /*
  * Perhaps this would be better to have a dummy initProxyWithCoder
@@ -320,18 +340,31 @@ static NSImage *testingImage = nil;
     {
       [[[self palettesManager] panel] makeKeyAndOrderFront: self];
     }
-  if((a = [defaults arrayForKey: @"GSAppKitUserBundles"]) != nil)
+  if((a = [defaults arrayForKey: @"GSAppKitUserBundles"]) != nil ||
+     _illegalClassSubstitution == YES)
     {
       if([a count] > 0)
 	{
-	  NSLog(@"WARNING: Gorm has detected that you are using user bundles.  Please make certain that these are compatible with Gorm as some bundles can cause issues which may corrupt your .gorm files.");
+	  NSRunAlertPanel(_(@"User Bundle Warning"), 
+			  _(@"Gorm has detected that you are using user bundles.  Please make certain that these are compatible with Gorm as some bundles can cause issues which may corrupt your .gorm files."),
+			  _(@"OK"), nil, nil);
 	}
+
+      if(_illegalClassSubstitution == YES)
+	{
+	  NSRunAlertPanel(_(@"Illegal Class Substitution"), 
+			  _(@"A bundle has invoked 'poseAsClass:', this could corrupt .gorm files.  Quitting."),
+			  _(@"OK"), nil, nil);
+	  NSBeep();
+	  [self terminate: self];
+	}
+
     }
   if(GSGetMethod([GSNibContainer class],@selector(awakeWithContext:),YES,YES) == NULL)
     {
       NSRunAlertPanel(_(@"Incorrect GNUstep Version"), 
 		      _(@"The version of GNUstep you are using is too old for this version of Gorm, please update."),
-		      _(@"OK"), NULL, NULL);
+		      _(@"OK"), nil, nil);
       [self terminate: self];
     }
 }
@@ -373,8 +406,11 @@ static NSImage *testingImage = nil;
    if (edited == YES)
      {
        int	result;
-       result = NSRunAlertPanel(NULL, _(@"There are edited windows"),
-				_(@"Review Unsaved"),_( @"Quit Anyway"), _(@"Cancel"));
+       result = NSRunAlertPanel(_(@"Quit"), 
+				_(@"There are edited windows"),
+				_(@"Review Unsaved"),
+				_( @"Quit Anyway"),
+				_(@"Cancel"));
       if (result == NSAlertDefaultReturn) 
 	{ 	  
 	  enumerator = [ documents objectEnumerator];
@@ -408,11 +444,6 @@ static NSImage *testingImage = nil;
   
 }
 
-
-/***********************************************************************/
-/***********************   Info Menu Actions****************************/
-/***********************************************************************/
-
 - (id) connectDestination
 {
   return connectDestination;
@@ -423,7 +454,6 @@ static NSImage *testingImage = nil;
   return connectSource;
 }
 
-
 - (void) displayConnectionBetween: (id)source
 			      and: (id)destination
 {
@@ -435,8 +465,8 @@ static NSImage *testingImage = nil;
     {
       if (connectSource != nil)
 	{
-	  window = [[self activeDocument] windowAndRect: &rect
-					 forObject: connectSource];
+	  window = [(GormDocument *)[self activeDocument] windowAndRect: &rect
+				    forObject: connectSource];
 	  if (window != nil)
 	    {
 	      NSView	*view = [[window contentView] superview];
@@ -459,8 +489,8 @@ static NSImage *testingImage = nil;
     {
       if (connectDestination != nil)
 	{
-	  window = [[self activeDocument] windowAndRect: &rect
-					  forObject: connectDestination];
+	  window = [(GormDocument *)[self activeDocument] windowAndRect: &rect
+				    forObject: connectDestination];
 	  if (window != nil)
 	    {
 	      NSView	*view = [[window contentView] superview];
@@ -482,19 +512,20 @@ static NSImage *testingImage = nil;
     }
   if (connectSource != nil)
     {
-      window = [[self activeDocument] windowAndRect: &rect forObject: connectSource];
+      window = [(GormDocument *)[self activeDocument] windowAndRect: &rect forObject: connectSource];
       if (window != nil)
 	{
 	  NSView	*view = [[window contentView] superview];
-	  
-	  rect.origin.x++;
-	  rect.size.width--;
-	  rect.size.height--;
+	  NSRect        imageRect = rect;
+
+	  imageRect.origin.x++;
+	  //rect.size.width--;
+	  //rect.size.height--;
 	  [view lockFocus];
 	  [[NSColor greenColor] set];
-	  NSFrameRectWithWidth(rect, 2);
+	  NSFrameRectWithWidth(rect, 1);
 	  
-	  [sourceImage compositeToPoint: rect.origin
+	  [sourceImage compositeToPoint: imageRect.origin
 			      operation: NSCompositeSourceOver];
 	  [view unlockFocus];
 	  [window flushWindow];
@@ -502,22 +533,23 @@ static NSImage *testingImage = nil;
     }
   if (connectDestination != nil && connectDestination == connectSource)
     {
-      window = [[self activeDocument] windowAndRect: &rect
-				     forObject: connectDestination];
+      window = [(GormDocument *)[self activeDocument] windowAndRect: &rect
+				forObject: connectDestination];
       if (window != nil)
 	{
 	  NSView	*view = [[window contentView] superview];
+	  NSRect        imageRect = rect;
 
-	  rect.origin.x += 3;
-	  rect.origin.y += 2;
-	  rect.size.width -= 5;
-	  rect.size.height -= 5;
+	  imageRect.origin.x += 3;
+	  imageRect.origin.y += 2;
+	  // rect.size.width -= 5;
+	  // rect.size.height -= 5;
 	  [view lockFocus];
 	  [[NSColor purpleColor] set];
-	  NSFrameRectWithWidth(rect, 2);
+	  NSFrameRectWithWidth(rect, 1);
 	  
-	  rect.origin.x += [targetImage size].width;
-	  [targetImage compositeToPoint: rect.origin
+	  imageRect.origin.x += [targetImage size].width;
+	  [targetImage compositeToPoint: imageRect.origin
 			      operation: NSCompositeSourceOver];
 	  [view unlockFocus];
 	  [window flushWindow];
@@ -525,20 +557,21 @@ static NSImage *testingImage = nil;
     }
   else if (connectDestination != nil)
     {
-      window = [[self activeDocument] windowAndRect: &rect
-				      forObject: connectDestination];
+      window = [(GormDocument *)[self activeDocument] windowAndRect: &rect
+				forObject: connectDestination];
       if (window != nil)
 	{
 	  NSView	*view = [[window contentView] superview];
+	  NSRect        imageRect = rect;
 
-	  rect.origin.x++;
-	  rect.size.width--;
-	  rect.size.height--;
+	  imageRect.origin.x++;
+	  // rect.size.width--;
+	  // rect.size.height--;
 	  [view lockFocus];
 	  [[NSColor purpleColor] set];
-	  NSFrameRectWithWidth(rect, 2);
+	  NSFrameRectWithWidth(rect, 1);
 	  
-	  [targetImage compositeToPoint: rect.origin
+	  [targetImage compositeToPoint: imageRect.origin
 			      operation: NSCompositeSourceOver];
 	  [view unlockFocus];
 	  [window flushWindow];
@@ -546,11 +579,7 @@ static NSImage *testingImage = nil;
     }
 }
 
-
-
-/***********************************************************************/
-/*********************** Info Menu Actions  ****************************/
-/***********************************************************************/
+/** Info Menu Actions */
 
 - (void) preferencesPanel: (id) sender
 {
@@ -562,10 +591,8 @@ static NSImage *testingImage = nil;
   [[preferencesController window] makeKeyAndOrderFront:nil];
 }
 
+/** Document Menu Actions */
 
-/***********************************************************************/
-/***********************  Document Menu Actions*************************/
-/***********************************************************************/
 - (void) open: (id) sender
 {
   GormDocument	*doc = AUTORELEASE([GormDocument new]);
@@ -583,8 +610,6 @@ static NSImage *testingImage = nil;
     }
 }
 
-
-//include Modules Menu
 - (void) newGormDocument : (id) sender 
 {
   id doc = AUTORELEASE([GormDocument new]);
@@ -690,15 +715,27 @@ static NSImage *testingImage = nil;
 	{
 	  NSUserDefaults	*defaults;
 	  NSNotificationCenter	*notifCenter = [NSNotificationCenter defaultCenter];
-	  GormDocument		*activDoc = (GormDocument*)[self activeDocument];
+	  GormDocument		*activeDoc = (GormDocument*)[self activeDocument];
 	  NSData		*data;
 	  NSArchiver            *archiver;
-	  
-	  
+	  NSEnumerator          *en;
+	  id                    obj;
+
+	  // which windows were open when testing started...
+	  testingWindows = [[NSMutableArray alloc] init]; 
+	  en = [[self windows] objectEnumerator];
+	  while((obj = [en nextObject]) != nil)
+	    {
+	      if([obj isVisible])
+		{
+		  [testingWindows addObject: obj];
+		}
+	    }
+
 	  isTesting = YES; // set here, so that beginArchiving and endArchiving do not use templates.
 	  [self setApplicationIconImage: testingImage];
 	  archiver = [[NSArchiver alloc] init];
-	  [activDoc beginArchiving];
+	  [activeDoc beginArchiving];
 	  [archiver encodeClassName: @"GormCustomView" 
 		    intoClassName: @"GormTestCustomView"];
 	  [archiver encodeClassName: @"GormNSMenu"
@@ -720,9 +757,9 @@ static NSImage *testingImage = nil;
 		    intoClassName: @"NSOutlineView"];
 	  */
 	  [GSClassSwapper setIsInInterfaceBuilder: YES]; // do not allow custom classes during testing.
-	  [archiver encodeRootObject: activDoc];
+	  [archiver encodeRootObject: activeDoc];
 	  data = RETAIN([archiver archiverData]); // Released below... 
-	  [activDoc endArchiving];
+	  [activeDoc endArchiving];
 	  RELEASE(archiver);
 	  [GSClassSwapper setIsInInterfaceBuilder: NO]; // beginal allowing custom classes...
 	  
@@ -790,7 +827,7 @@ static NSImage *testingImage = nil;
 
 	  // display the current main menu...
 	  [[self mainMenu] display];
-	  
+
 	  [notifCenter postNotificationName: IBDidBeginTestingInterfaceNotification
 		       object: self];
 	  
@@ -801,9 +838,11 @@ static NSImage *testingImage = nil;
 	  // reset the application after the error.
 	  NSLog(@"Error while testing interface: %@", 
 		[localException reason]);
-	  NSRunAlertPanel(_(@"An Error Occurred"), [NSString stringWithFormat: @"Problem testing interface.  Make sure connections are to appropriate objects.  Exception: %@",
-					  [localException reason]], 
-			  _(@"OK"), NULL, NULL);
+	  NSRunAlertPanel(_(@"An Error Occurred"), 
+			  [NSString stringWithFormat: 
+				      @"Problem testing interface.  Make sure connections are to appropriate objects.  Exception: %@",
+				    [localException reason]], 
+			  _(@"OK"), nil, nil);
 	  [self endTesting: self];
 	}
       NS_ENDHANDLER;
@@ -811,9 +850,7 @@ static NSImage *testingImage = nil;
 }
 
 
-/***********************************************************************/
-/***********************   Edit Menu Actions*****************************/
-/***********************************************************************/
+/** Edit Menu Actions */
 
 - (void) copy: (id)sender
 {
@@ -821,7 +858,12 @@ static NSImage *testingImage = nil;
       || [selectionOwner respondsToSelector: @selector(copySelection)] == NO)
     return;
   
-  [(GormGenericEditor *)selectionOwner copySelection];
+  if([self isConnecting])
+    {
+      [self stopConnecting];
+    }
+
+  [(id<IBSelectionOwners,IBEditors>)selectionOwner copySelection];
 }
 
 
@@ -831,8 +873,14 @@ static NSImage *testingImage = nil;
       || [selectionOwner respondsToSelector: @selector(copySelection)] == NO
       || [selectionOwner respondsToSelector: @selector(deleteSelection)] == NO)
     return;
-  [(GormGenericEditor *)selectionOwner copySelection];
-  [(GormGenericEditor *)selectionOwner deleteSelection];
+
+  if([self isConnecting])
+    {
+      [self stopConnecting];
+    }
+
+  [(id<IBSelectionOwners,IBEditors>)selectionOwner copySelection];
+  [(id<IBSelectionOwners,IBEditors>)selectionOwner deleteSelection];
 }
 
 - (void) paste: (id)sender
@@ -840,7 +888,12 @@ static NSImage *testingImage = nil;
   if ([selectionOwner respondsToSelector: @selector(pasteInSelection)] == NO)
     return;
 
-  [(GormGenericEditor *)selectionOwner pasteInSelection];
+  if([self isConnecting])
+    {
+      [self stopConnecting];
+    }
+
+  [(id<IBSelectionOwners,IBEditors>)selectionOwner pasteInSelection];
 }
 
 
@@ -849,7 +902,13 @@ static NSImage *testingImage = nil;
   if ([[selectionOwner selection] count] == 0
     || [selectionOwner respondsToSelector: @selector(deleteSelection)] == NO)
     return;
-  [(GormGenericEditor *)selectionOwner deleteSelection];
+
+  if([self isConnecting])
+    {
+      [self stopConnecting];
+    }
+
+  [(id<IBSelectionOwners,IBEditors>)selectionOwner deleteSelection];
 }
 
 - (void) selectAllItems: (id)sender
@@ -911,9 +970,7 @@ static NSImage *testingImage = nil;
   [[NSFontManager sharedFontManager] orderFrontFontPanel: self];
 }
 
-/***********************************************************************/
-/***********************   Group Action  *******************************/
-/***********************************************************************/
+/** Grouping */
 
 - (void) groupSelectionInSplitView: (id)sender
 {
@@ -946,7 +1003,7 @@ static NSImage *testingImage = nil;
   [(GormGenericEditor *)selectionOwner ungroup];
 }
 
-/// Classes actions...
+/** Classes actions */
 
 - (void) createSubclass: (id)sender
 {
@@ -980,7 +1037,7 @@ static NSImage *testingImage = nil;
   [(GormDocument *)[self activeDocument] remove: sender];
 }
 
-/// Palettes Actions...
+/** Palettes Actions... */
 
 - (void) inspector: (id) sender
 {
@@ -997,7 +1054,7 @@ static NSImage *testingImage = nil;
   [[self palettesManager] openPalette: sender];
 }
 
-/// Testing methods...
+/** Testing methods... */
 
 - (void) deferredEndTesting: (id) sender
 {
@@ -1024,6 +1081,7 @@ static NSImage *testingImage = nil;
       NSUserDefaults		*defaults;
       NSEnumerator		*e;
       id			val;
+
       CREATE_AUTORELEASE_POOL(pool);
 
       [nc postNotificationName: IBWillEndTestingInterfaceNotification
@@ -1041,6 +1099,21 @@ static NSImage *testingImage = nil;
 	    }
 	}
 
+      /*
+       * Make sure any peripheral windows: font panels, etc. which are brought
+       * up by the interface being tested are also closed.
+       */
+      e = [[self windows] objectEnumerator];
+      while ((val = [e nextObject]) != nil)
+	{
+	  if ([testingWindows containsObject: val] == NO && 
+	      [val isKindOfClass: [NSWindow class]] &&
+	      [val isVisible])
+	    {
+	      [val orderOut: self];
+	    }
+	}
+
       // prevent saving of this, if the menuLocations have not previously been set.
       if(menuLocations != nil)
 	{
@@ -1073,6 +1146,9 @@ static NSImage *testingImage = nil;
       [nc postNotificationName: IBDidEndTestingInterfaceNotification
 			object: self];
       
+
+      DESTROY(testingWindows);
+
       RELEASE(pool);
 
       return self;
@@ -1144,7 +1220,7 @@ static NSImage *testingImage = nil;
 {
   if (inspectorsManager == nil)
     {
-      inspectorsManager = [GormInspectorsManager new];
+      inspectorsManager = (GormInspectorsManager *)[GormInspectorsManager sharedInspectorManager];
     }
   return inspectorsManager;
 }
@@ -1243,6 +1319,8 @@ static NSImage *testingImage = nil;
 {
   [self displayConnectionBetween: nil and: nil];
   isConnecting = NO;
+  connectSource = nil;
+  connectDestination = nil;
 }
 
 - (BOOL) validateMenuItem: (NSMenuItem*)item
@@ -1253,10 +1331,12 @@ static NSImage *testingImage = nil;
   NSArray	*s = [selectionOwner selection];
 
   // temporarily disabling this functionality....
+  /*
   if (sel_eq(action, @selector(loadClass:)))
     {
       return NO;
     }
+  */
 
   if (sel_eq(action, @selector(close:))
     || sel_eq(action, @selector(miniaturize:))
@@ -1407,8 +1487,7 @@ static NSImage *testingImage = nil;
 	    return NO;
 	}
       
-      if(sel_eq(action, @selector(addAttributeToClass:)) ||
-	 sel_eq(action, @selector(createClassFiles:)) || 
+      if(sel_eq(action, @selector(createClassFiles:)) || 
 	 sel_eq(action, @selector(remove:)))
 	{
 	  id o = nil;
