@@ -28,9 +28,10 @@
 
 #include <AppKit/AppKit.h>
 #include "GormClassInspector.h"
-#include "GormPrivate.h"
 #include "GormClassManager.h"
 #include "GormDocument.h"
+#include "GormFunctions.h"
+#include "GormPrivate.h"
 #include <InterfaceBuilder/IBApplicationAdditions.h>
 
 NSNotificationCenter *nc = nil;
@@ -108,7 +109,7 @@ objectValueForTableColumn: (NSTableColumn *)tc
   NSString *currentClass = [inspector _currentClass];
   NSArray *list = [classManager allOutletsForClassNamed: currentClass];
   NSString *name = [list objectAtIndex: rowIndex];
-  NSString *formattedOutlet = [GormDocument formatOutlet: anObject];
+  NSString *formattedOutlet = formatOutlet( (NSString *)anObject );
   GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
   
   if(![name isEqual: anObject])
@@ -163,7 +164,7 @@ objectValueForTableColumn: (NSTableColumn *)tc
   NSString *currentClass = [inspector _currentClass];
   NSArray *list = [classManager allActionsForClassNamed: currentClass];
   NSString *name = [list objectAtIndex: rowIndex];
-  NSString *formattedAction = [GormDocument formatAction: anObject];
+  NSString *formattedAction = formatAction( (NSString *)anObject );
   GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
 
   if(![name isEqual: anObject])
@@ -291,6 +292,7 @@ objectValueForTableColumn: (NSTableColumn *)tc
   [outletTable setDataSource: outletData];
   [parentClass setDataSource: parentClassData];
   [parentClass setDoubleAction: @selector(selectClass:)];
+  [parentClass setTarget: self];
 
   // delegate...
   [actionTable setDelegate: self];
@@ -306,7 +308,7 @@ objectValueForTableColumn: (NSTableColumn *)tc
   id removeOutletCell = [removeOutlet cell];
   id selectClassCell = [selectClass cell];
   id searchCell = [search cell];
-  BOOL isCustom = [classManager isCustomClass: [self _currentClass]];
+  BOOL isEditable = [classManager isCustomClass: [self _currentClass]]; 
   BOOL isFirstResponder = [[self _currentClass] isEqualToString: @"FirstResponder"];
   NSArray *list = [classManager allClassNames];
   NSString *superClass = [classManager parentOfClass: [self _currentClass]];
@@ -318,22 +320,22 @@ objectValueForTableColumn: (NSTableColumn *)tc
   [parentClass reloadData];
 
   // activate for actions...
-  [addActionCell setEnabled: isCustom];
-  [removeActionCell setEnabled: isCustom];
+  [addActionCell setEnabled: YES]; //isEditable];
+  [removeActionCell setEnabled: YES]; //isEditable];
 
   // activate for outlet...
-  [addOutletCell setEnabled: (isCustom && !isFirstResponder)];
-  [removeOutletCell setEnabled: (isCustom && !isFirstResponder)];
+  [addOutletCell setEnabled: (isEditable && !isFirstResponder)];
+  [removeOutletCell setEnabled: (isEditable && !isFirstResponder)];
 
   // activate select class...
-  [selectClassCell setEnabled: (isCustom && !isFirstResponder)];
-  [parentClass setEnabled: (isCustom && !isFirstResponder)];
-  [searchCell setEnabled: (isCustom && !isFirstResponder)];
-  [classField setEditable: (isCustom && !isFirstResponder)];
-  [classField setBackgroundColor: (isCustom?[NSColor whiteColor]:[NSColor lightGrayColor])];
+  [selectClassCell setEnabled: (isEditable && !isFirstResponder)];
+  [parentClass setEnabled: (isEditable && !isFirstResponder)];
+  [searchCell setEnabled: (isEditable && !isFirstResponder)];
+  [classField setEditable: (isEditable && !isFirstResponder)];
+  [classField setBackgroundColor: ((isEditable && !isFirstResponder)?[NSColor whiteColor]:[NSColor lightGrayColor])];
 
   // select the parent class
-  if(index != NSNotFound)
+  if(index != NSNotFound && list != nil)
     {
       [parentClass selectRow: index byExtendingSelection: NO];
       [parentClass scrollRowToVisible: index];
@@ -342,94 +344,157 @@ objectValueForTableColumn: (NSTableColumn *)tc
 
 - (void) addAction: (id)sender
 {
-  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
-  NSString *className = [self _currentClass];
-
-  [classManager addNewActionToClassNamed: className];
-  [document collapseClass: className];
-  [document reloadClasses];
-  [nc postNotificationName: IBInspectorDidModifyObjectNotification
-		    object: classManager];
-  [actionTable reloadData];
-  [document selectClass: className];
+  NS_DURING
+    {
+      GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
+      if(document != nil)
+	{
+	  NSString *className = [self _currentClass];
+	  NSString *newAction = [classManager addNewActionToClassNamed: className];  
+	  NSArray *list = [classManager allActionsForClassNamed: className];
+	  int row = [list indexOfObject: newAction];
+	  
+	  [document collapseClass: className];
+	  [document reloadClasses];
+	  [nc postNotificationName: IBInspectorDidModifyObjectNotification
+	      object: classManager];
+	  [actionTable reloadData];
+	  [actionTable scrollRowToVisible: row];
+	  [actionTable selectRow: row byExtendingSelection: NO];
+	  [document selectClass: className];
+	  [super ok: sender];
+	}
+    }
+  NS_HANDLER
+    {
+      NSLog(@"%@",[localException reason]);
+    }
+  NS_ENDHANDLER;
 }
 
 - (void) addOutlet: (id)sender
 {
-  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
-  NSString *className = [self _currentClass];
-
-  [classManager addNewOutletToClassNamed: className];  
-  [document collapseClass: className];
-  [document reloadClasses];
-  [nc postNotificationName: IBInspectorDidModifyObjectNotification
-		    object: classManager];
-  [outletTable reloadData];
-  [document selectClass: className];
+  NS_DURING
+    {
+      GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
+      if(document != nil)
+	{
+	  NSString *className = [self _currentClass];
+	  NSString *newOutlet = [classManager addNewOutletToClassNamed: className];  
+	  NSArray *list = [classManager allOutletsForClassNamed: className];
+	  int row = [list indexOfObject: newOutlet];
+	  
+	  [document collapseClass: className];
+	  [document reloadClasses];
+	  [nc postNotificationName: IBInspectorDidModifyObjectNotification
+	      object: classManager];
+	  [outletTable reloadData];
+	  [outletTable scrollRowToVisible: row];
+	  [outletTable selectRow: row byExtendingSelection: NO];
+	  [document selectClass: className];
+	  [super ok: sender];
+	}
+    }
+  NS_HANDLER
+    {
+      NSLog(@"%@",[localException reason]);
+    }
+  NS_ENDHANDLER;
 }
 
 - (void) removeAction: (id)sender
 {
-  int i = [actionTable selectedRow];
-  NSString *className = [self _currentClass];
-  NSArray *list = [classManager allActionsForClassNamed: className];
-  BOOL removed = NO;
-  NSString *name = nil;
-  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
-
-  // check the count...
-  if([list count] > 0 && i >= 0 && i < [list count])
+  NS_DURING
     {
-      [actionTable deselectAll: self];
-      name = [list objectAtIndex: i];
-      removed = [document 
-		  removeConnectionsWithLabel: name 
-		  forClassNamed: currentClass
-		  isAction: YES];
+      int i = [actionTable selectedRow];
+      NSString *className = [self _currentClass];
+      NSArray *list = [classManager allActionsForClassNamed: className];
+      BOOL removed = NO;
+      BOOL isCustom = [classManager isCustomClass: className]; 
+      NSString *name = nil;
+      GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
+      
+      if(document != nil)
+	{
+	  // check the count...
+	  if(isCustom || [classManager isCategoryForClass: className])
+	    {
+	      if([list count] > 0 && i >= 0 && i < [list count])
+		{
+		  [actionTable deselectAll: self];
+		  name = [list objectAtIndex: i];
+		  if(isCustom || [classManager isAction: name onCategoryForClassNamed: className])
+		    {
+		      removed = [document 
+				  removeConnectionsWithLabel: name 
+				  forClassNamed: currentClass
+				  isAction: YES];
+		    }
+		}
+	      
+	      if(removed)
+		{
+		  [super ok: sender];
+		  [document collapseClass: className];
+		  [document reloadClasses];
+		  [classManager removeAction: name fromClassNamed: className];
+		  [nc postNotificationName: IBInspectorDidModifyObjectNotification
+		      object: classManager];
+		  [actionTable reloadData];
+		  [document selectClass: className];
+		}
+	    }
+	}
     }
-
-  if(removed)
+  NS_HANDLER
     {
-      [document collapseClass: className];
-      [document reloadClasses];
-      [classManager removeAction: name fromClassNamed: className];
-      [nc postNotificationName: IBInspectorDidModifyObjectNotification
-	  object: classManager];
-      [actionTable reloadData];
-      [document selectClass: className];
+      NSLog(@"%@",[localException reason]);
     }
+  NS_ENDHANDLER;
 }
 
 - (void) removeOutlet: (id)sender
 {
-  int i = [outletTable selectedRow];
-  NSString *className = [self _currentClass];
-  NSArray *list = [classManager allOutletsForClassNamed: className];
-  BOOL removed = NO;
-  NSString *name = nil;
-  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
-
-  // check the count...
-  if([list count] > 0 && i >= 0 && i < [list count])
+  NS_DURING
     {
-      [outletTable deselectAll: self];
-      name = [list objectAtIndex: i];
-      removed = [document 
-		  removeConnectionsWithLabel: name 
-		  forClassNamed: currentClass
-		  isAction: NO];
+      int i = [outletTable selectedRow];
+      NSString *className = [self _currentClass];
+      NSArray *list = [classManager allOutletsForClassNamed: className];
+      BOOL removed = NO;
+      NSString *name = nil;
+      GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
+      
+      if(document != nil)
+	{ 
+	  // check the count...
+	  if([list count] > 0 && i >= 0 && i < [list count])
+	    {
+	      [outletTable deselectAll: self];
+	      name = [list objectAtIndex: i];
+	      removed = [document 
+			  removeConnectionsWithLabel: name 
+			  forClassNamed: currentClass
+			  isAction: NO];
+	    }
+	  
+	  if(removed)
+	    {
+	      [super ok: sender];
+	      [document collapseClass: className];
+	      [document reloadClasses];
+	      [classManager removeOutlet: name fromClassNamed: className];
+	      [nc postNotificationName: IBInspectorDidModifyObjectNotification
+		  object: classManager];
+	      [outletTable reloadData];
+	      [document selectClass: className];
+	    }
+	}
     }
-
-  if(removed)
+  NS_HANDLER
     {
-      [document collapseClass: className];
-      [document reloadClasses];
-      [classManager removeOutlet: name fromClassNamed: className];
-      [nc postNotificationName: IBInspectorDidModifyObjectNotification
-	  object: classManager];
-      [outletTable reloadData];
-      [document selectClass: className];
+      NSLog(@"%@",[localException reason]);
     }
+  NS_ENDHANDLER;
 }
 
 - (void) select: (id)sender
@@ -444,7 +509,8 @@ objectValueForTableColumn: (NSTableColumn *)tc
   int index = [list indexOfObject: stringValue];
 
   NSLog(@"Search... %@",[searchText stringValue]);
-  if(index != NSNotFound && [stringValue isEqualToString: @"FirstResponder"] == NO)
+  if(index != NSNotFound && list != nil && 
+     [stringValue isEqualToString: @"FirstResponder"] == NO)
     {
       // select the parent class
       [parentClass selectRow: index byExtendingSelection: NO];
@@ -456,27 +522,48 @@ objectValueForTableColumn: (NSTableColumn *)tc
 {
   NSArray *list = [classManager allClassNames];
   int row = [parentClass selectedRow];
-  NSString *newParent = [list objectAtIndex: row];
-  NSString *name = [self _currentClass];
-  BOOL removed = NO;
-  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
 
-  // check to see if the user wants to do this and remove the connections.
-  removed = [document removeConnectionsForClassNamed: name]; 
-
-  // if removed, move the class and notify... 
-  if(removed)
+  NS_DURING
     {
-      NSString *oldSuper = [classManager superClassNameForClassNamed: name];
-      
-      [classManager setSuperClassNamed: newParent forClassNamed: name];
-      [nc postNotificationName: IBInspectorDidModifyObjectNotification
-	  object: classManager];
-      [document collapseClass: oldSuper];
-      [document collapseClass: name];
-      [document reloadClasses];
-      [document selectClass: name];
+      if(row >= 0)
+	{
+	  NSString *newParent = [list objectAtIndex: row];
+	  NSString *name = [self _currentClass];
+	  BOOL removed = NO;
+	  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
+	  
+	  // if it's a custom class, let it go, if not do nothing.
+	  if(document != nil)
+	    {
+	      if([classManager isCustomClass: name])
+		{     
+		  [super ok: sender];
+		  
+		  // check to see if the user wants to do this and remove the connections.
+		  removed = [document removeConnectionsForClassNamed: name]; 
+		  
+		  // if removed, move the class and notify... 
+		  if(removed)
+		    {
+		      NSString *oldSuper = [classManager superClassNameForClassNamed: name];
+		      
+		      [classManager setSuperClassNamed: newParent forClassNamed: name];
+		      [nc postNotificationName: IBInspectorDidModifyObjectNotification
+			  object: classManager];
+		      [document collapseClass: oldSuper];
+		      [document collapseClass: name];
+		      [document reloadClasses];
+		      [document selectClass: name];
+		    }
+		}
+	    }
+	}
     }
+  NS_HANDLER
+    {
+      NSLog(@"%@",[localException reason]);
+    }
+  NS_ENDHANDLER;
 }
 
 - (void) changeClassName: (id)sender
@@ -498,6 +585,7 @@ objectValueForTableColumn: (NSTableColumn *)tc
 	  object: classManager];
       [document reloadClasses];
       [document selectClass: newName];
+      [super ok: sender];
     }
 }
 
@@ -508,9 +596,23 @@ objectValueForTableColumn: (NSTableColumn *)tc
 
 - (void) setObject: (id)anObject
 {
+  int outletsCount = 0;
+  int actionsCount = 0;
+  NSTabViewItem *item = nil;
+
   [super setObject: anObject];
   ASSIGN(classManager, [(Gorm *)NSApp classManager]);
   ASSIGN(currentClass, [object className]);
+
+  outletsCount = [[classManager allOutletsForClassNamed: currentClass] count];
+  actionsCount = [[classManager allActionsForClassNamed: currentClass] count];
+
+  item = [tabView tabViewItemAtIndex: 1]; // actions;
+  [item setLabel: [NSString stringWithFormat: @"Actions (%d)",actionsCount]];
+  item = [tabView tabViewItemAtIndex: 0]; // outlets;
+  [item setLabel: [NSString stringWithFormat: @"Outlets (%d)",outletsCount]];
+  [tabView setNeedsDisplay: YES];
+
   [self _refreshView];
 }
 
@@ -521,7 +623,8 @@ objectValueForTableColumn: (NSTableColumn *)tc
 
 - (void) handleNotification: (NSNotification *)notification
 {
-  if([notification object] == classManager)
+  if([notification object] == classManager &&
+     [(id<IB>)NSApp activeDocument] != nil)
     {
       [self _refreshView];
     }
@@ -538,16 +641,14 @@ shouldEditTableColumn: (NSTableColumn *)aTableColumn
     {
       NSArray *list = nil;
       NSString *name = nil;
-      NSTabViewItem *tvi = [tabView selectedTabViewItem];
-      BOOL isAction = [[tvi identifier] isEqualToString: @"Actions"];
       NSString *className = [self _currentClass];
       
-      if(isAction)
+      if(tableView == actionTable)
 	{
 	  list = [classManager allActionsForClassNamed: className];
 	  name = [list objectAtIndex: rowIndex];
 	}
-      else
+      else if(tableView == outletTable)
 	{
 	  list = [classManager allOutletsForClassNamed: className];
 	  name = [list objectAtIndex: rowIndex];
@@ -555,22 +656,63 @@ shouldEditTableColumn: (NSTableColumn *)aTableColumn
       
       if([classManager isCustomClass: className])
 	{
-	  if (isAction)
+	  if(tableView == actionTable)
 	    {
 	      result = [classManager isAction: name
 				     ofClass: className];
 	    }
-	  else 
+	  else if(tableView == outletTable)
 	    {
 	      result = [classManager isOutlet: name
 				     ofClass: className];
 	    }	       
 	}
+      else 
+	{
+	  result = [classManager isAction: name onCategoryForClassNamed: className];
+	}
     }
 
   return result;
 }
 
+/*
+- (void) tableView: (NSTableView *)tableView
+   willDisplayCell: (id)aCell
+    forTableColumn: (NSTableColumn *)aTableColumn
+	       row: (int)rowIndex
+{
+  NSString *name = [aCell stringValue];
+  NSString *className = [self _currentClass];
+
+  if(tableView == actionTable)
+    {
+      if(([classManager isCustomClass: className] &&
+	  [classManager isAction: name ofClass: className]) ||
+	 [classManager isAction: name onCategoryForClassNamed: className])
+	{
+	  [aCell setTextColor: [NSColor blackColor]];
+	}
+      else
+	{
+	  [aCell setTextColor: [NSColor darkGrayColor]];
+	}
+    }
+  else if(tableView == outletTable)
+    {
+      if([classManager isCustomClass: className] &&
+	 [classManager isOutlet: name ofClass: className])
+	{
+	  [aCell setTextColor: [NSColor blackColor]];
+	}
+      else
+	{
+	  [aCell setTextColor: [NSColor darkGrayColor]];
+	}
+    }
+}
+*/
+
 - (BOOL) tableView: (NSTableView *)tv
    shouldSelectRow: (int)rowIndex
 {
