@@ -23,19 +23,18 @@
  */
 
 #include <AppKit/AppKit.h>
-
+#include <Foundation/NSArchiver.h>
 #include "GormPrivate.h"
-
 #include "GormViewWithSubviewsEditor.h"
 #include "GormControlEditor.h"
-
 #include "GormPlacementInfo.h"
+#include <InterfaceBuilder/IBObjectAdditions.h>
 
 #define _EO ((NSControl *)_editedObject)
 
 @class GormWindowEditor;
 
-@implementation NSControl (GormObjectAdditions)
+@implementation NSControl (IBObjectAdditions)
 - (NSString*) editorClassName
 {
   return @"GormControlEditor";
@@ -605,7 +604,7 @@
 }
 @end
 
-@implementation NSTextField (GormObjectAdditions)
+@implementation NSTextField (IBObjectAdditions)
 - (NSString*) editorClassName
 {
   return @"GormTextFieldEditor";
@@ -621,8 +620,8 @@
 @implementation GormTextFieldEditor
 - (void) mouseDown:  (NSEvent*)theEvent
 {
+  // double-clicked -> let's edit
   if (([theEvent clickCount] == 2) && [parent isOpened])
-    // double-clicked -> let's edit
     {
       [self editTextField: _editedObject
 	    withEvent: theEvent];
@@ -635,5 +634,96 @@
       [super mouseDown: theEvent];
     }
 }
+
+- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
+{
+  NSPasteboard	*dragPb;
+  NSArray	*types;
+  unsigned       result = NSDragOperationNone;
+
+  dragPb = [sender draggingPasteboard];
+  types = [dragPb types];
+  if ([types containsObject: IBFormatterPboardType] == YES)
+    {
+      result = NSDragOperationCopy;
+    }
+  else
+    {
+      result = [super draggingEntered: sender];
+    }
+
+  return result;
+}
+
+- (BOOL) performDragOperation: (id<NSDraggingInfo>)sender
+{
+  NSPasteboard	*dragPb;
+  NSArray	*types;
+  BOOL           result = NO;
+
+  dragPb = [sender draggingPasteboard];
+  types = [dragPb types];
+  
+  if ([types containsObject: IBFormatterPboardType] == YES)
+    {
+      NSData *data = [dragPb dataForType: IBFormatterPboardType];
+      id array = RETAIN([NSUnarchiver unarchiveObjectWithData: data]);
+      
+      if(array != nil)
+	{
+	  if([array count] > 0)
+	    {
+	      id object = [array objectAtIndex: 0];
+
+	      if([_editedObject respondsToSelector: @selector(setFormatter:)])
+		{
+		  id fieldValue = nil;
+
+		  [_editedObject setFormatter: object];	      
+		  if ([object isMemberOfClass: [NSNumberFormatter class]])
+		    {
+		      fieldValue = [NSNumber numberWithFloat: 1.123456789];
+		      [_editedObject setStringValue: [fieldValue stringValue]];
+		      [_editedObject setObjectValue: fieldValue];
+		    }
+		  else if ([object isMemberOfClass: [NSDateFormatter class]])
+		    {
+		      fieldValue = [NSDate date];
+		      [_editedObject setStringValue: [fieldValue description]];
+		      [_editedObject setObjectValue: fieldValue];
+		    }
+		  
+		  result = YES;
+		}
+	    }
+	}
+    }
+  else
+    {
+      [super performDragOperation: sender];
+    }
+
+  return result;
+}
+
+- (BOOL) prepareForDragOperation: (id<NSDraggingInfo>)sender
+{
+  NSPasteboard	*dragPb;
+  NSArray	*types;
+  BOOL           result = NO;
+
+  dragPb = [sender draggingPasteboard];
+  types = [dragPb types];
+  if ([types containsObject: IBFormatterPboardType] == YES)
+    {
+      result = YES;
+    }
+  else
+    {
+      result = [super prepareForDragOperation: sender];
+    }
+
+  return result;
+}
 @end
 
