@@ -30,7 +30,7 @@
 #include <Foundation/Foundation.h>
 #include <GNUstepGUI/GSNibTemplates.h>
 
-@class GormClassManager, GormClassEditor, GormObjectProxy;
+@class GormClassManager, GormClassEditor, GormObjectProxy, GormFilesOwner;
 
 /*
  * Each document has a GormFirstResponder object that is used as a placeholder
@@ -128,16 +128,14 @@
 // classes support..
 - (id) createSubclass: (id)sender;
 - (id) instantiateClass: (id)sender;
-- (id) editClass: (id)sender;
 - (id) createClassFiles: (id)sender;
-- (void) changeCurrentClass: (id)sender;
 - (id) addAttributeToClass: (id)sender;
 - (id) remove: (id)sender;
 - (id) createClassFiles: (id)sender;
 - (id) instantiateClass: (id)sender;
-- (void) selectClassWithObject: (id)obj;
 - (void) selectClass: (NSString *)className;
 - (BOOL) classIsSelected;
+- (void) removeAllInstancesOfClass: (NSString *)classNamed;
 
 // sound & image support
 - (id) openSound: (id)sender;
@@ -163,14 +161,13 @@
 - (void) setWindowsMenu: (NSMenu *)menu;
 - (NSMenu *) windowsMenu;
 
-// utility methods...
-+ (NSString*) identifierString: (NSString*)str;
-+ (NSString *)formatAction: (NSString *)action;
-+ (NSString *)formatOutlet: (NSString *)outlet;
-
 // first responder/font manager
 - (id) fontManager;
 - (id) firstResponder;
+
+// windowAndRect:forObject: is called by Gorm to determine where it should
+// draw selection markup
+- (NSWindow*) windowAndRect: (NSRect*)r forObject: (id)object;
 @end
 
 @interface GormDocument (MenuValidation)
