@@ -1,3 +1,28 @@
+/* GormGenericEditor.m
+ *
+ * Copyright (C) 1999, 2003 Free Software Foundation, Inc.
+ *
+ * Author:	Pierre-Yves Rivaille <pyrivail@ens-lyon.fr>
+ * Author:	Gregory John Casamento <greg_casamento@yahoo.com>
+ * Date:	1999, 2003
+ * 
+ * This file is part of GNUstep.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include "GormPrivate.h"
 
 @implementation	GormGenericEditor
@@ -315,4 +340,15 @@
 {
   return (closed == NO);
 }
+
+// stubs for protocol methods not implemented in this editor.
+- (void) validateEditing
+{
+  // does nothing.
+}
+
+- (void) drawSelection
+{
+  // does nothing.
+}
 @end
