@@ -26,6 +26,7 @@
 #include "GormFunctions.h"
 #include "GormPalettesManager.h"
 #include <AppKit/NSImage.h>
+#include "GormImage.h"
 
 /*
  * Method to return the image that should be used to display objects within
@@ -36,7 +37,6 @@
 {
   return @"GormImageInspector";
 }
-
 @end
 
 
@@ -138,7 +138,7 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
  	  id placeHolder =  nil;
 
 	  NSLog(@"====> %@",[data objectAtIndex:i]);
-	  placeHolder = [(GormDocument *)document _createImagePlaceHolder: [data objectAtIndex: i]];
+	  placeHolder = [GormImage imageForPath: [data objectAtIndex: i]];
  	  NSLog(@"here1 %@", [data objectAtIndex: i]);
 
 	  if (placeHolder)
@@ -240,11 +240,9 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
       en = [list objectEnumerator];
       while((obj = [en nextObject]) != nil)
 	{
-	  NSString *name = [[obj lastPathComponent] stringByDeletingPathExtension];
-	  GormImage *image = [[GormImage alloc] initWithName: name path: obj];
+	  GormImage *image = [GormImage imageForPath: obj];
 	  [image setSystemImage: YES];
 	  [self addObject: image];
-	  RELEASE(image);
 	}
 
       // set up the notification...
@@ -257,6 +255,18 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
   return self;
 }
 
+- (void) dealloc
+{
+  if(closed == NO)
+    [self close];
+
+  // TODO: This is a band-aid fix until I find the actual problem. 
+  // This *WILL* leak, but I don't want it crashing on people.
+  
+  RELEASE(objects);
+  NSDebugLog(@"Released...");
+}
+
 - (void) close
 {
   [super close];
@@ -264,6 +274,22 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
   NSMapRemove(docMap,document);
 }
 
+- (void) addObject: (id)anObject
+{
+  if([objects containsObject: anObject] == NO)
+    {
+      [super addObject: anObject];
+    }
+  else
+    {
+      NSRunAlertPanel (_(@"Problem adding image"), 
+		       _(@"An image with the same name exists, remove it first."), 
+		       _(@"OK"), 
+		       nil, 
+		       nil);      
+    }
+}
+
 - (void) makeSelectionVisible: (BOOL)flag
 {
   if (flag == YES && selected != nil)
@@ -363,18 +389,22 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
 	  int pos;
 	  pos = row * [self numberOfColumns] + column;
 
-  	  pb = [NSPasteboard pasteboardWithName: NSDragPboard];
-  	  [pb declareTypes: [NSArray arrayWithObject: GormImagePboardType]
-  		     owner: self];
-  	  [pb setString: [[objects objectAtIndex: pos] imageName] 
-	      forType: GormImagePboardType];
-  	  [self dragImage: [[objects objectAtIndex: pos] image]
-  		       at: lastLocation
-  		   offset: NSZeroSize
+	  // don't allow the user to drag empty resources.
+	  if(pos < [objects count])
+	    {
+	      pb = [NSPasteboard pasteboardWithName: NSDragPboard];
+	      [pb declareTypes: [NSArray arrayWithObject: GormImagePboardType]
+		  owner: self];
+	      [pb setString: [[objects objectAtIndex: pos] imageName] 
+		  forType: GormImagePboardType];
+	      [self dragImage: [[objects objectAtIndex: pos] image]
+		    at: lastLocation
+		    offset: NSZeroSize
   		    event: theEvent
-  	       pasteboard: pb
-  		   source: self
-  		slideBack: YES];
+		    pasteboard: pb
+		    source: self
+		    slideBack: YES];
+	    }
 
 	  return;
 	}
@@ -397,6 +427,26 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
 {
 }
 
+- (void) deleteSelection
+{
+  if(![selected isSystemImage])
+    {
+      if([selected isInWrapper])
+	{
+	  NSFileManager *mgr = [NSFileManager defaultManager];
+	  NSString *path = [selected imagePath];
+	  BOOL removed = [mgr removeFileAtPath: path
+			      handler: nil];
+	  if(!removed)
+	    {
+	      NSString *msg = [NSString stringWithFormat: @"Could not delete file %@", path];
+	      NSLog(msg);
+	    }
+	}
+      [super deleteSelection];
+    }
+}
+
 - (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag
 {
   return NSDragOperationCopy;
@@ -449,7 +499,7 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
       id		obj = [objects objectAtIndex: index];
       NSButtonCell	*but = [self cellAtRow: index/cols column: index%cols];
       NSString          *name = [obj imageName];
-      
+
       [but setImage: [obj image]];
       [but setTitle: name];
       [but setShowsStateBy: NSChangeGrayCellMask];
@@ -479,126 +529,4 @@ static int handled_mask= NSDragOperationCopy|NSDragOperationGeneric|NSDragOperat
 */
 @end
 
-// image proxy object...
-@implementation GormImage
-- (id) initWithName: (NSString *)aName
-	       path: (NSString *)aPath
-{
-  NSSize originalSize;
-  float ratioH;
-  float ratioW;
-  [super init];
-  ASSIGN(name, aName);
-  ASSIGN(path, aPath);
-  image = [[NSImage alloc] initByReferencingFile: aPath];
-  smallImage = [[NSImage alloc] initWithContentsOfFile: aPath];
-  [image setName: aName];
 
-  if (smallImage == nil)
-    {
-      RELEASE(name);
-      RELEASE(path);
-      return nil;
-    }
-
-  originalSize = [smallImage size];
-  ratioW = originalSize.width / 70;
-  ratioH = originalSize.height / 55;
-  
-  if (ratioH > 1 || ratioW > 1)
-    {
-      [smallImage setScalesWhenResized: YES];
-      if (ratioH > ratioW)
-	{
-	  [smallImage setSize: NSMakeSize(originalSize.width / ratioH, 55)];
-	}
-      else 
-	{
-	  [smallImage setSize: NSMakeSize(70, originalSize.height / ratioW)];
-	}
-    }
-
-  isSystemImage = NO;
-  isInWrapper = NO;
-  return self;
-}
-
-- (void) dealloc
-{
-  RELEASE(name);
-  RELEASE(path);
-  RELEASE(image);
-  RELEASE(smallImage);
-  [super dealloc];
-}
-
-- (void) setImageName: (NSString *)aName
-{
-  ASSIGN(name, aName);
-}
-
-- (NSString *) imageName
-{
-  return name;
-}
-
-- (void) setImagePath: (NSString *)aPath
-{
-  ASSIGN(path, aPath);
-}
-
-- (NSString *) imagePath
-{
-  return path;
-}
-
-- (NSImage *) normalImage
-{
-  return image;
-}
-
-- (NSImage *) image
-{
-  return smallImage;
-}
-
-- (void) setSystemImage: (BOOL)flag
-{
-  isSystemImage = flag;
-}
-
-- (BOOL) isSystemImage
-{
-  return isSystemImage;
-}
-
-- (void) setInWrapper: (BOOL)flag
-{
-  isInWrapper = flag;
-}
-
-- (BOOL) isInWrapper
-{
-  return isInWrapper;
-}
-
-- (NSString *)inspectorClassName
-{
-  return @"GormImageInspector"; 
-}
-
-- (NSString*) classInspectorClassName
-{
-  return @"GormNotApplicableInspector";
-}
-
-- (NSString*) connectInspectorClassName
-{
-  return @"GormNotApplicableInspector";
-}
-
-- (NSString*) sizeInspectorClassName
-{
-  return @"GormNotApplicableInspector";
-}
-@end
