@@ -26,6 +26,7 @@
 #include "GormPrivate.h"
 #include "GormInternalViewEditor.h"
 #include "GormFontViewController.h"
+#include <InterfaceBuilder/IBObjectAdditions.h>
 
 @class GormEditorToParent;
 
@@ -41,7 +42,7 @@ static NSImage *horizontalImage;
 #endif
 
 
-@implementation NSView (GormObjectAdditions)
+@implementation NSView (IBObjectAdditions)
 - (NSString*) editorClassName
 {
   if ([self superview] && 
@@ -220,6 +221,16 @@ static NSImage *horizontalImage;
 - (id) initWithObject: (id)anObject 
 	   inDocument: (id<IBDocuments>)aDocument
 {
+  NSMutableArray *types = 
+    [NSMutableArray arrayWithObjects: IBViewPboardType, 
+		    GormLinkPboardType, nil];
+
+  // if the object can take a formatter, add it to the list.
+  if([anObject respondsToSelector: @selector(setFormatter:)])
+    {
+      [types addObject: IBFormatterPboardType];
+    }
+
   opened = NO;
   openedSubeditor = nil;
 
@@ -230,8 +241,7 @@ static NSImage *horizontalImage;
   selection = [[NSMutableArray alloc] initWithCapacity: 5];
   
   [self registerForDraggedTypes: [NSArray arrayWithObjects:
-    IBViewPboardType, GormLinkPboardType, IBFormatterPboardType, nil]];
-  
+    IBViewPboardType, GormLinkPboardType, IBFormatterPboardType, nil]];  
 
   if (horizontalImage == nil)
     {
@@ -313,36 +323,32 @@ static NSImage *horizontalImage;
 {
   BOOL onKnob = NO;
 
-  {
-    if ([parent respondsToSelector: @selector(selection)] &&
-	[[parent selection] containsObject: _editedObject])
-      {
-	IBKnobPosition	knob = IBNoneKnobPosition;
-	NSPoint mouseDownPoint = 
-	  [self convertPoint: [theEvent locationInWindow]
-		fromView: nil];
-	knob = GormKnobHitInRect([self bounds], 
-				 mouseDownPoint);
-	if (knob != IBNoneKnobPosition)
-	  onKnob = YES;
-      }
-    if (onKnob == YES)
-      {
-	if (parent)
-	  return [parent mouseDown: theEvent];
-	else
-	  return [self noResponderFor: @selector(mouseDown:)];
-      }
-  }
+  if ([parent respondsToSelector: @selector(selection)] &&
+      [[parent selection] containsObject: _editedObject])
+    {
+      IBKnobPosition	knob = IBNoneKnobPosition;
+      NSPoint mouseDownPoint = 
+	[self convertPoint: [theEvent locationInWindow]
+	      fromView: nil];
+      knob = GormKnobHitInRect([self bounds], 
+			       mouseDownPoint);
+      if (knob != IBNoneKnobPosition)
+	onKnob = YES;
+    }
+  if (onKnob == YES)
+    {
+      if (parent)
+	return [parent mouseDown: theEvent];
+      else
+	return [self noResponderFor: @selector(mouseDown:)];
+    }
   
-  {
-    if ([parent isOpened] == NO)
-      {
-	NSDebugLog(@"md %@ calling my parent %@", self, parent);
-	[parent mouseDown: theEvent];
-	return;
-      }
-  }
+  if ([parent isOpened] == NO)
+    {
+      NSDebugLog(@"md %@ calling my parent %@", self, parent);
+      [parent mouseDown: theEvent];
+      return;
+    }
 
   // are we on the knob of a selected view ?
   {
@@ -438,7 +444,7 @@ static NSImage *horizontalImage;
 	  }
 	else
 	  {
-	    NSLog(@"WARNING -- strange case");
+	    NSDebugLog(@"WARNING -- strange case");
 	    result = self;
 	  }
       }
