@@ -26,7 +26,7 @@
 #define INCLUDED_IBEDITORS_H
 
 #include <Foundation/NSObject.h>
-#include <InterfaceBuilder/IBDocuments.h>
+#include <InterfaceBuilder/IBSystem.h>
 
 // forward references
 @class NSString;
@@ -36,35 +36,46 @@
 /*
  * Notification for editing and inspecting the objects etc.
  */
-extern NSString *IBAttributesChangedNotification;
-extern NSString *IBInspectorDidModifyObjectNotification;
-extern NSString *IBSelectionChangedNotification;
-extern NSString *IBClassNameChangedNotification;
+IB_EXTERN NSString *IBAttributesChangedNotification;
+IB_EXTERN NSString *IBInspectorDidModifyObjectNotification;
+IB_EXTERN NSString *IBSelectionChangedNotification;
+IB_EXTERN NSString *IBClassNameChangedNotification;
 
 /**
  * The IBSelectionOwners protocol defines the methods that a selection owner
  * must implement.
  */
 @protocol IBSelectionOwners <NSObject>
-//  - (unsigned) selectionCount;
-- (NSArray*) selection;
-//  - (void) drawSelection;
+/**
+ * The number of currently selected objects.
+ */
+- (unsigned) selectionCount;
 
-/*
+/**
+ * Return the selection in an array.
+ */
+- (NSArray*) selection;
+
+/**
+ * Draw the selection.
+ */
+- (void) drawSelection;
+
+/**
  * This method is used to draw or remove markup that identifies selected
  * objects within the object being edited.
  */
 - (void) makeSelectionVisible: (BOOL)flag;
 
-/*
+/**
  * This method changes the current selection to those objects in the array.
  */
 - (void) selectObjects: (NSArray*)objects;
 
-//  /*
-//   * This method places the current selection from the editor on the pasteboard.
-//   */
-//  - (void) copySelection;
+/**
+ * This method places the current selection from the editor on the pasteboard.
+ */
+- (void) copySelection;
 
 @end
 
@@ -97,6 +108,11 @@ extern NSString *IBClassNameChangedNotification;
  */
 - (void) close;
 
+/**
+ * Close all subeditors associated with this editor.
+ */
+- (void) closeSubeditors;
+
 /**
  * Deactivate an editor - removes it from the view hierarchy so that objects
  * can be archived without including the editor.
@@ -105,10 +121,10 @@ extern NSString *IBClassNameChangedNotification;
  */
 - (void) deactivate;
 
-//  /*
-//   * This method deletes all the objects in the current selection in the editor.
-//   */
-//  - (void) deleteSelection;
+/**
+ * This method deletes all the objects in the current selection in the editor.
+ */
+- (void) deleteSelection;
 
 /**
  * This method returns the document that owns the object that the editor edits.
@@ -125,11 +141,18 @@ extern NSString *IBClassNameChangedNotification;
  */
 - (void) orderFront;
 
+/**
+ * Opens the subeditor for an object when the object being edited is
+ * double clicked by the user.  If there is no sub-editor, return nil, otherwise
+ * method will return the editor for the object.
+ */
+- (id<IBEditors>) openSubeditorForObject: (id)object;
+
 /**
  * This method is used to add the contents of the pasteboard to the current
  * selection of objects within the editor.
  */
-//  - (void) pasteInSelection;
+- (void) pasteInSelection;
 
 /**
  * Redraws the edited object
@@ -143,6 +166,12 @@ extern NSString *IBClassNameChangedNotification;
  */
 - (BOOL) wantsSelection;
 
+/**
+ * Causes the editor to select the text being edited in the current text
+ * field.
+ */
+- (void) validateEditing;
+
 /**
  * This returns the window in which the editor is drawn.
  */
