@@ -61,7 +61,10 @@
  */
 - (NSString *)nibLabel: (NSString *)objectName
 {
-  return nil;
+  NSString *label = [NSString stringWithFormat: @"%@(%@)",
+			      [self className],
+			      objectName];
+  return label;
 }
 
 /**
@@ -69,7 +72,7 @@
  */
 - (NSString *)objectNameForInspectorTitle
 {
-  return NSStringFromClass([self class]);
+  return [self className];
 }
 
 /**
