@@ -1,4 +1,4 @@
-/* IBInspector.h
+/* IBPalette.h
  *
  * Copyright (C) 2003 Free Software Foundation, Inc.
  *
@@ -28,6 +28,7 @@
 #include <Foundation/NSMapTable.h>
 #include <Foundation/NSObject.h>
 #include <InterfaceBuilder/IBDocuments.h>
+#include <InterfaceBuilder/IBSystem.h>
 
 // forward references
 @class NSString;
@@ -40,22 +41,22 @@
  * window into another window in Gorm (or, in the case of IBWindowPboardType
  * onto the desktop).
  */
-extern NSString	*IBCellPboardType;
-extern NSString	*IBMenuPboardType;
-extern NSString	*IBMenuCellPboardType;
-extern NSString	*IBObjectPboardType;
-extern NSString	*IBViewPboardType;
-extern NSString	*IBWindowPboardType;
-extern NSString	*IBFormatterPboardType;
+IB_EXTERN NSString	*IBCellPboardType;
+IB_EXTERN NSString	*IBMenuPboardType;
+IB_EXTERN NSString	*IBMenuCellPboardType;
+IB_EXTERN NSString	*IBObjectPboardType;
+IB_EXTERN NSString	*IBViewPboardType;
+IB_EXTERN NSString	*IBWindowPboardType;
+IB_EXTERN NSString	*IBFormatterPboardType;
 
 /*
  * Pasteboard types used for DnD from images or sounds tab
- * to views or inspector's textfield
- * onto the desktop).
- * NOTE: These are specific to Gorm... */
-extern NSString	*GormImagePboardType;
-extern NSString	*GormSoundPboardType;
-extern NSString *GormLinkPboardType;
+ * to views or inspector's textfield onto the desktop).
+ * NOTE: These are specific to Gorm... 
+ */
+IB_EXTERN NSString	*GormImagePboardType;
+IB_EXTERN NSString	*GormSoundPboardType;
+IB_EXTERN NSString      *GormLinkPboardType;
 
 @interface IBPalette : NSObject
 {
