@@ -25,20 +25,10 @@
 #ifndef INCLUDED_IBVIEWADDITIONS_H
 #define INCLUDED_IBVIEWADDITIONS_H
 
-#include <InterfaceBuilder/IBDefines.h>
-#include <Foundation/NSGeometry.h>
+#include <InterfaceBuilder/IBViewProtocol.h>
 #include <AppKit/NSView.h>
 
-// forward references
-@class NSColor;
-
-@interface NSView (ViewAdditions)
-- (BOOL) acceptsColor: (NSColor*)color atPoint: (NSPoint)point;
-- (BOOL) allowsAltDragging;
-- (void) depositColor: (NSColor*)color atPoint: (NSPoint)point;
-- (NSSize) maximumSizeFromKnobPosition: (IBKnobPosition)knobPosition;
-- (NSSize) minimumSizeFromKnobPosition: (IBKnobPosition)position;
-- (void) placeView: (NSRect)newFrame;
+@interface NSView (IBViewAdditions) <IBViewProtocol>
 @end
 
 #endif
