@@ -24,12 +24,27 @@
 
 #include "GormPrivate.h"
 #include "GormFunctions.h"
+#include <InterfaceBuilder/IBObjectAdditions.h>
 
 /*
  * Method to return the image that should be used to display objects within
  * the matrix containing the objects in a document.
  */
 @implementation NSObject (GormObjectAdditions)
+- (NSImage*) imageForViewer
+{
+  static NSImage	*image = nil;
+
+  if (image == nil)
+    {
+      NSBundle	*bundle = [NSBundle mainBundle];
+      NSString *path = [bundle pathForImageResource: @"GormUnknown"]; 
+      image = [[NSImage alloc] initWithContentsOfFile: path];
+    }
+
+  return image;
+}
+
 - (NSString*) inspectorClassName
 {
   return @"GormObjectInspector";
@@ -54,23 +69,8 @@
 {
   return @"GormObjectEditor";
 }
-- (NSImage*) imageForViewer
-{
-  static NSImage	*image = nil;
-
-  if (image == nil)
-    {
-      NSBundle	*bundle = [NSBundle mainBundle];
-      NSString *path = [bundle pathForImageResource: @"GormUnknown"]; 
-      image = [[NSImage alloc] initWithContentsOfFile: path];
-    }
-
-  return image;
-}
 @end
 
-
-
 @implementation	GormObjectEditor
 
 static NSMapTable	*docMap = 0;
@@ -111,6 +111,10 @@ static NSMapTable	*docMap = 0;
   return NO;
 }
 
+- (void) pasteInSelection
+{
+}
+
 - (void) copySelection
 {
   if (selected != nil)
@@ -169,6 +173,27 @@ static NSMapTable	*docMap = 0;
     }
 }
 
+- (void) removeAllInstancesOfClass: (NSString *)className
+{
+  GormClassManager *classManager = [(GormDocument *)document classManager];
+  NSMutableArray *removedObjects = [NSMutableArray array];
+  NSEnumerator *en = [objects objectEnumerator];
+  id object = nil;
+
+  // locate objects for removal
+  while((object = [en nextObject]) != nil)
+    {
+      NSString *clsForObj = [classManager classNameForObject: object];
+      if([className isEqual: clsForObj])
+	{
+	  [removedObjects addObject: object];
+	}
+    }
+
+  // remove the objects
+  [document detachObjects: removedObjects];
+}
+
 /*
  *	Dragging source protocol implementation
  */
@@ -390,11 +415,6 @@ static NSMapTable	*docMap = 0;
   [super mouseDown: theEvent];
 }
 
-
-- (void) pasteInSelection
-{
-}
-
 - (BOOL) performDragOperation: (id<NSDraggingInfo>)sender
 {
   if (dragType == IBObjectPboardType)
