@@ -186,8 +186,8 @@ static NSImage	*dragImage = nil;
 
   if (active == nil)
     {
-      NSRunAlertPanel (NULL, _(@"No document is currently active"), 
-		       _(@"OK"), NULL, NULL);
+      NSRunAlertPanel (nil, _(@"No document is currently active"), 
+		       _(@"OK"), nil, nil);
       return;
     }
 
@@ -357,7 +357,7 @@ static NSImage	*dragImage = nil;
   return self;
 }
 
-- (void) loadPalette: (NSString*)path
+- (BOOL) loadPalette: (NSString*)path
 {
   NSBundle	*bundle;
   NSWindow	*window;
@@ -370,67 +370,93 @@ static NSImage	*dragImage = nil;
   IBPalette	*palette;
   NSImageCell	*cell;
   int		col;
-  
+
   for (col = 0; col < [bundles count]; col++)
     {
       bundle = [bundles objectAtIndex: col];
       if ([path isEqualToString: [bundle bundlePath]] == YES)
 	{
-	  NSRunAlertPanel (NULL, _(@"Palette has already been loaded"), 
-			   _(@"OK"), NULL, NULL);
-	  return;
+	  NSRunAlertPanel (nil, _(@"Palette has already been loaded"), 
+			   _(@"OK"), nil, nil);
+	  return NO;
 	}
     }
   bundle = [NSBundle bundleWithPath: path]; 
   if (bundle == nil)
     {
-      NSRunAlertPanel(NULL, _(@"Could not load Palette"), 
-		      _(@"OK"), NULL, NULL);
-      return;
+      NSRunAlertPanel(nil, _(@"Could not load Palette"), 
+		      _(@"OK"), nil, nil);
+      return NO;
     }
-  [bundles addObject: bundle];	
 
   path = [bundle pathForResource: @"palette" ofType: @"table"];
   if (path == nil)
     {
-      NSRunAlertPanel(NULL, _(@"File 'palette.table' missing"),
-		      _(@"OK"), NULL, NULL);
-      return;
+      NSRunAlertPanel(nil, _(@"File 'palette.table' missing"),
+		      _(@"OK"), nil, nil);
+      return NO;
     }
 
-  paletteInfo = [[NSString stringWithContentsOfFile: path] propertyList];
-  if (paletteInfo == nil)
+  // attempt to load the palette table in either the strings or plist format.
+  NS_DURING
     {
-      NSRunAlertPanel(NULL, _(@"Failed to load 'palette.table', you may need to update GNUstep-make and do a clean build of Gorm and it's palettes."),
-		      _(@"OK"), NULL, NULL);
-      return;
+      paletteInfo = [[NSString stringWithContentsOfFile: path] propertyList];
+      if (paletteInfo == nil)
+	{
+	  paletteInfo = [[NSString stringWithContentsOfFile: path] propertyListFromStringsFileFormat];
+	  if(paletteInfo == nil)
+	    {
+	      NSRunAlertPanel(_(@"Problem Loading Palette"), 
+			      _(@"Failed to load 'palette.table' using strings or property list format."),
+			      _(@"OK"), 
+			      nil, 
+			      nil);
+	      return NO;
+	    }
+	}
     }
+  NS_HANDLER
+    {
+      NSString *message = [NSString stringWithFormat: 
+				      _(@"Encountered exception %@ attempting to load 'palette.table'."),
+				    [localException reason]];
+      NSRunAlertPanel(_(@"Problem Loading Palette"), 
+		      message,
+		      _(@"OK"), 
+		      nil, 
+		      nil);
+      return NO;
+    }
+  NS_ENDHANDLER
 
   className = [paletteInfo objectForKey: @"Class"];
   if (className == nil)
     {
-      NSRunAlertPanel(NULL, _(@"No palette class in 'palette.table'"),
-		      _(@"OK"), NULL, NULL);
-      return;
+      NSRunAlertPanel(nil, _(@"No palette class in 'palette.table'"),
+		      _(@"OK"), nil, nil);
+      return NO;
     }
 
   paletteClass = [bundle classNamed: className];
   if (paletteClass == 0)
     {
-      NSRunAlertPanel (NULL, _(@"Could not load palette class"), 
-		       _(@"OK"), NULL, NULL);
-      return;
+      NSRunAlertPanel (nil, _(@"Could not load palette class"), 
+		       _(@"OK"), nil, nil);
+      return NO;
     }
 
   palette = [paletteClass new];
   if ([palette isKindOfClass: [IBPalette class]] == NO)
     {
-      NSRunAlertPanel (NULL, _(@"Palette contains wrong type of class"), 
-		       _(@"OK"), NULL, NULL);
+      NSRunAlertPanel (nil, _(@"Palette contains wrong type of class"), 
+		       _(@"OK"), nil, nil);
       RELEASE(palette);
-      return;
+      return NO;
     }
 
+  // add to the bundles list...
+  [bundles addObject: bundle];	
+
   exportClasses = [paletteInfo objectForKey: @"ExportClasses"];
   if(exportClasses != nil)
     {
@@ -475,6 +501,8 @@ static NSImage	*dragImage = nil;
   [selectionView selectCellAtRow: 0 column: col];
   [self setCurrentPalette: selectionView];
   RELEASE(palette);
+
+  return YES;
 }
 
 - (id) openPalette: (id) sender
@@ -505,7 +533,10 @@ static NSImage	*dragImage = nil;
 	  NSString	*aFile = [filesToOpen objectAtIndex: i];
 
 	  [newUserPalettes addObject: aFile];
-	  [self loadPalette: aFile];
+	  if([self loadPalette: aFile] == NO)
+	    {
+	      return nil;
+	    }
 	}
 
       // reset the defaults to include the new palette.
