@@ -30,7 +30,9 @@
 @class	GormInspectorsManager;
 @class	GormPalettesManager;
 
-#include <InterfaceBuilder/InterfaceBuilder.h>
+#include <InterfaceBuilder/IBApplicationAdditions.h>
+#include <InterfaceBuilder/IBInspector.h>
+#include <InterfaceBuilder/IBViewAdditions.h>
 #include "GormFilesOwner.h"
 #include "GormDocument.h"
 #include "GormInspectorsManager.h"
@@ -111,6 +113,7 @@ extern NSString *GormResizeCellNotification;
   NSWindow		*connectDWindow;
   NSRect		connectDRect;
   NSPoint               cascadePoint;
+  NSMutableArray        *testingWindows;
 }
 - (id<IBDocuments>) activeDocument;
 - (id) connectSource;
@@ -167,11 +170,21 @@ extern NSString *GormResizeCellNotification;
 @interface GormClassEditor : GormOutlineView <IBSelectionOwners>
 {
   GormDocument          *document;
-  NSString              *selectedClassName;
+  GormClassManager      *classManager;
+  NSString              *selectedClass;
 }
 - (GormClassEditor*) initWithDocument: (GormDocument*)doc;
 + (GormClassEditor*) classEditorForDocument: (GormDocument*)doc;
 - (void) setSelectedClassName: (NSString*)cn;
+- (NSString *) selectedClassName;
+- (void) selectClassWithObject: (id)obj editClass: (BOOL)flag;
+- (void) selectClassWithObject: (id)obj;
+- (void) selectClass: (NSString *)className editClass: (BOOL)flag;
+- (void) selectClass: (NSString *)className;
+- (BOOL) currentSelectionIsClass;
+- (void) editClass;
+- (void) createSubclass;
+- (void) deleteSelection;
 @end
 
 @interface	GormGenericEditor : NSMatrix <IBEditors, IBSelectionOwners>
@@ -198,7 +211,7 @@ extern NSString *GormResizeCellNotification;
 - (void) refreshCells;
 - (void) removeObject: (id)anObject;
 - (BOOL) activate;
-- (id) initWithObject: (id)anObject inDocument: (id<IBDocuments>)aDocument;
+- (id) initWithObject: (id)anObject inDocument: (id)aDocument;
 - (void) close;
 - (void) closeSubeditors;
 - (BOOL) containsObject: (id)anObject;
@@ -225,17 +238,19 @@ extern NSString *GormResizeCellNotification;
 - (id) changeSelection: (id)sender;
 @end
 
-@interface	GormObjectEditor : GormGenericEditor 
+@interface GormObjectEditor : GormGenericEditor 
 {
 }
++ (void) setEditor: (id)editor forDocument: (id<IBDocuments>)aDocument;
 - (void) draggedImage: (NSImage*)i endedAt: (NSPoint)p deposited: (BOOL)f;
 - (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag;
 - (BOOL) acceptsTypeFromArray: (NSArray*)types;
 - (void) makeSelectionVisible: (BOOL)flag;
 - (void) resetObject: (id)anObject;
+- (void) removeAllInstancesOfClass: (NSString *)className;
 @end
 
-@interface	GormSoundEditor : GormGenericEditor 
+@interface GormSoundEditor : GormGenericEditor 
 {
 }
 + (GormSoundEditor*) editorForDocument: (id<IBDocuments>)aDocument;
@@ -243,7 +258,7 @@ extern NSString *GormResizeCellNotification;
 - (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag;
 @end
 
-@interface	GormImageEditor : GormGenericEditor 
+@interface GormImageEditor : GormGenericEditor 
 {
 }
 - (void) draggedImage: (NSImage*)i endedAt: (NSPoint)p deposited: (BOOL)f;
@@ -251,16 +266,6 @@ extern NSString *GormResizeCellNotification;
 - (void) refreshCells;
 @end
 
-
-@interface GormFilesOwnerInspector : IBInspector
-{
-  NSBrowser	*browser;
-  NSArray	*classes;
-  BOOL		hasConnections;
-}
-- (void) takeClassFrom: (id)sender;
-@end
-
 /*
  * NSDateFormatter and NSNumberFormatter extensions
  * for Gorm Formatters used in the Data Palette
@@ -299,58 +304,6 @@ extern NSString *GormResizeCellNotification;
 - (NSImage *) imageForViewer;
 @end
 
-// we don't use the actual sound since we don't want to read the entire sound into
-// memory.
-@interface GormSound : NSObject
-{
-  NSString *name;
-  NSString *path;
-  BOOL     isSystemSound;
-  BOOL     isInWrapper; 
-}
-- (id) initWithName: (NSString *)aName
-               path: (NSString *)aPath;
-- (void) setSoundName: (NSString *)aName;
-- (NSString *) soundName;
-- (void) setSoundPath: (NSString *)aPath;
-- (NSString *) soundPath;
-- (void) setSystemSound: (BOOL)flag;
-- (BOOL) isSystemSound;
-- (void) setInWrapper: (BOOL)flag;
-- (BOOL) isInWrapper;
-- (NSString *)inspectorClassName;
-@end
-
-@interface GormImage : NSObject
-{
-  NSString *name;
-  NSString *path;
-  NSImage  *image;
-  NSImage  *smallImage;
-  BOOL     isSystemImage;
-  BOOL     isInWrapper; 
-}
-- (id) initWithName: (NSString *)aName
-               path: (NSString *)aPath;
-- (void) setImageName: (NSString *)aName;
-- (NSString *) imageName;
-- (void) setImagePath: (NSString *)aPath;
-- (NSString *) imagePath;
-- (void) setSystemImage: (BOOL)flag;
-- (BOOL) isSystemImage;
-- (void) setInWrapper: (BOOL)flag;
-- (BOOL) isInWrapper;
-- (NSString *)inspectorClassName;
-- (NSImage *)image;
-- (NSImage *)normalImage;
-@end
-
-@interface GormDocument (PrivateMethodsForImagesAndSounds)
-- (GormImage *)_createImagePlaceHolder: (NSString *)path;
-- (GormSound *)_createSoundPlaceHolder: (NSString *)path;
-- (void) addImage: (NSString*) path;
-@end
-
 /*
  * Functions for drawing knobs etc.
  */
