@@ -26,6 +26,7 @@
 #include "GormFunctions.h"
 #include "GormPalettesManager.h"
 #include <AppKit/NSSound.h>
+#include "GormSound.h"
 
 /*
  * Method to return the image that should be used to display objects within
@@ -242,8 +243,7 @@ static NSMapTable	*docMap = 0;
       en = [list objectEnumerator];
       while((obj = [en nextObject]) != nil)
 	{
-	  NSString *name = [[obj lastPathComponent] stringByDeletingPathExtension];
-	  GormSound *sound = [[GormSound alloc] initWithName: name path: obj];
+	  GormSound *sound = [GormSound soundForPath: obj];
 	  [sound setSystemSound: YES];
 	  [self addObject: sound];
 	}
@@ -265,6 +265,22 @@ static NSMapTable	*docMap = 0;
   NSMapRemove(docMap,document);
 }
 
+- (void) addObject: (id)anObject
+{
+  if([objects containsObject: anObject] == NO)
+    {
+      [super addObject: anObject];
+    }
+  else
+    {
+      NSRunAlertPanel (_(@"Problem adding sound"), 
+		       _(@"An sound with the same name exists, remove it first."), 
+		       _(@"OK"), 
+		       nil, 
+		       nil);      
+    }
+}
+
 - (void) makeSelectionVisible: (BOOL)flag
 {
   if (flag == YES && selected != nil)
@@ -364,18 +380,22 @@ static NSMapTable	*docMap = 0;
 	  int pos;
 	  pos = row * [self numberOfColumns] + column;
 
-  	  pb = [NSPasteboard pasteboardWithName: NSDragPboard];
-  	  [pb declareTypes: [NSArray arrayWithObject: GormSoundPboardType]
-  		     owner: self];
-  	  [pb setString: [[objects objectAtIndex: pos] soundName] 
-	      forType: GormSoundPboardType];
-  	  [self dragImage: [[objects objectAtIndex: pos] soundImageForViewer]
-  		       at: lastLocation
-  		   offset: NSZeroSize
+	  // don't allow the user to drag empty resources.
+	  if(pos < [objects count])
+	    {
+	      pb = [NSPasteboard pasteboardWithName: NSDragPboard];
+	      [pb declareTypes: [NSArray arrayWithObject: GormSoundPboardType]
+		  owner: self];
+	      [pb setString: [[objects objectAtIndex: pos] soundName] 
+		  forType: GormSoundPboardType];
+	      [self dragImage: [[objects objectAtIndex: pos] soundImageForViewer]
+		    at: lastLocation
+		    offset: NSZeroSize
   		    event: theEvent
-  	       pasteboard: pb
-  		   source: self
-  		slideBack: YES];
+		    pasteboard: pb
+		    source: self
+		    slideBack: YES];
+	    }
 
 	  return;
 	}
@@ -398,6 +418,26 @@ static NSMapTable	*docMap = 0;
 {
 }
 
+- (void) deleteSelection
+{
+  if(![selected isSystemSound])
+    {
+      if([selected isInWrapper])
+	{
+	  NSFileManager *mgr = [NSFileManager defaultManager];
+	  NSString *path = [selected soundPath];
+	  BOOL removed = [mgr removeFileAtPath: path
+			      handler: nil];
+	  if(!removed)
+	    {
+	      NSString *msg = [NSString stringWithFormat: @"Could not delete file %@", path];
+	      NSLog(msg);
+	    }
+	}
+      [super deleteSelection];
+    }
+}
+
 - (BOOL) performDragOperation: (id<NSDraggingInfo>)sender
 {
   if (dragType == IBObjectPboardType)
@@ -567,81 +607,3 @@ static NSMapTable	*docMap = 0;
 
 @end
 
-// sound proxy object...
-@implementation GormSound
-- (id) initWithName: (NSString *)aName
-	       path: (NSString *)aPath
-{
-  NSSound *sound = [[NSSound alloc] initWithContentsOfFile: aPath
-		   byReference: YES];
-  [super init];
-  ASSIGN(name, aName);
-  ASSIGN(path, aPath);
-
-  //#warning "we want to store the sound somewhere"
-  [(NSSound *)sound setName: aName];
-  isSystemSound = NO;
-  isInWrapper = NO;
-  return self;
-}
-
-- (void) setSoundName: (NSString *)aName
-{
-  ASSIGN(name, aName);
-}
-
-- (NSString *) soundName
-{
-  return name;
-}
-
-- (void) setSoundPath: (NSString *)aPath
-{
-  ASSIGN(path, aPath);
-}
-
-- (NSString *) soundPath
-{
-  return path;
-}
-
-- (void) setSystemSound: (BOOL)flag
-{
-  isSystemSound = flag;
-}
-
-- (BOOL) isSystemSound
-{
-  return isSystemSound;
-}
-
-- (void) setInWrapper: (BOOL)flag
-{
-  isInWrapper = flag;
-}
-
-- (BOOL) isInWrapper
-{
-  return isInWrapper;
-}
-
-- (NSString *)inspectorClassName
-{
-  return @"GormSoundInspector";
-}
-
-- (NSString*) classInspectorClassName
-{
-  return @"GormNotApplicableInspector";
-}
-
-- (NSString*) connectInspectorClassName
-{
-  return @"GormNotApplicableInspector";
-}
-
-- (NSString*) sizeInspectorClassName
-{
-  return @"GormNotApplicableInspector";
-}
-@end
