@@ -114,19 +114,6 @@
 }
 @end
 
-// to allow us to load the image by name, but save it within the archive.
-// this is a bit of a cheat.
-@interface NSImage (GormAddition)
-- (void) setArchiveByName: (BOOL) archiveByName;
-@end
-
-@implementation NSImage (GormAddition)
-- (void) setArchiveByName: (BOOL) archiveByName
-{
-  _flags.archiveByName = archiveByName;
-}
-@end
-
 static BOOL currently_displaying = NO;
 
 
@@ -164,17 +151,10 @@ static BOOL currently_displaying = NO;
     {
       NSView *superview;
 
-      // put the view into a "view window" if it's a standalone view...
-      if([_editedObject window] == nil)
+      // if the view window is not nil, it's a standalone view...
+      if(viewWindow != nil)
 	{
-	  if(viewWindow == nil)
-	    {
-	      viewWindow = [[GormViewWindow alloc] initWithView: _editedObject];
-	    }
-	  else
-	    {
-	      [viewWindow setView: _editedObject];
-	    }
+	  [viewWindow setView: _editedObject];
 	}
 
       superview = [_editedObject superview];
@@ -314,11 +294,23 @@ static BOOL currently_displaying = NO;
 	{
 	  [draggedTypes addObject: GormSoundPboardType];
 	}
+      if ([_editedObject respondsToSelector: @selector(setFormatter:)])
+	{
+	  [draggedTypes addObject: IBFormatterPboardType];
+	} 
       
       [self registerForDraggedTypes: draggedTypes];
       
       activated = NO;
       closed = NO;
+      
+      // if this window is nil when the editor is created, we know it's a
+      // standalone view.
+      if([anObject window] == nil)
+	{
+	  NSLog(@"#### Stand alone view: %@",_editedObject);
+	  viewWindow = [[GormViewWindow alloc] initWithView: _editedObject];
+	}
     }
 
   return self;
@@ -1333,9 +1325,12 @@ static BOOL currently_displaying = NO;
   else if ([types containsObject: GormImagePboardType] == YES)
     {
       NSString *name = [dragPb stringForType: GormImagePboardType];
-      NSImage *image = [NSImage imageNamed: name];
-      [image setArchiveByName: NO];
-      [(id)_editedObject setImage: image];
+      if([(id)_editedObject respondsToSelector: @selector(setImage:)])
+	{
+	  NSImage *image = [NSImage imageNamed: name];
+	  // [image setArchiveByName: NO];
+	  [(id)_editedObject setImage: AUTORELEASE([image copy])];
+	}
       return YES;
     }
   else   if ([types containsObject: GormSoundPboardType] == YES)
@@ -1344,7 +1339,8 @@ static BOOL currently_displaying = NO;
       name = [dragPb stringForType: GormSoundPboardType];
       if([(id)_editedObject respondsToSelector: @selector(setSound:)])
 	{
-	  [(id)_editedObject setSound: [NSSound soundNamed: name]];
+	  NSSound *sound = [NSSound soundNamed: name];
+	  [(id)_editedObject setSound: AUTORELEASE([sound copy])];
 	}
       return YES;
     }
@@ -1488,6 +1484,32 @@ static BOOL currently_displaying = NO;
       [self setNeedsDisplay: YES];
     }
 }
+
+// stubs for the remainder of the IBEditors protocol not implemented in this class.
+- (void) deleteSelection
+{
+  // NSLog(@"deleteSelection should be defined in a subclass");
+}
+
+- (void) validateEditing
+{
+  // NSLog(@"validateEditing should be defined in a subclass");
+}
+
+- (void) pasteInSelection
+{
+  // NSLog(@"deleteSelection should be defined in a subclass");
+}
+
+- (id<IBEditors>) openSubeditorForObject: (id) object
+{
+  return nil;
+}
+
+- (void) closeSubeditors
+{
+  // NSLog(@"closeSubeditors should be defined in a subclass");
+}
 @end
 
 
