@@ -532,7 +532,7 @@
       NSEnumerator	*e = [s objectEnumerator];
       NSMenuItem	*i;
       NSArray       *d = nil;
-      
+     
       [self makeSelectionVisible: NO];
       [self selectObjects: [NSArray array]];
       
@@ -780,20 +780,13 @@ void _attachAll(NSMenu *menu, id document)
     {
       NSString	*title = [item title];
 
-      if ([edited indexOfItemWithTitle: title] > 0)
+      if ([[self _menu] _ownedByPopUp])
 	{
-	  [document detachObject: item];	/* Already exists */
-	}
-      else
-	{
-	  if ([[self _menu] _ownedByPopUp])
-	    {
-	      [item setOnStateImage: nil];
-	      [item setMixedStateImage: nil];
-	    }
-	  [edited addItem: item];
-	  
+	  [item setOnStateImage: nil];
+	  [item setMixedStateImage: nil];
 	}
+      [edited addItem: item];
+      [document attachObject: item toParent: [self _menu]];
     }
   [edited sizeToFit];
   [edited display];
@@ -1063,6 +1056,8 @@ static BOOL done_editing;
   if ([name isEqual: NSControlTextDidEndEditingNotification] == YES)
     {
       done_editing = YES;
+      [document setSelectionFromEditor: self]; // Correction for Bug#11410
+      // [self selectObjects: [NSArray arrayWithObject: edited]];
     }
 }
 
