@@ -30,9 +30,12 @@
 @interface GormNSPanel : NSPanel
 {
   unsigned _gormStyleMask;
+  BOOL     _gormReleasedWhenClosed;
 }
-- (void) setStyleMask: (unsigned)newStyleMask;
-- (unsigned) styleMask;
+- (void) _setStyleMask: (unsigned int)newStyleMask;
+- (unsigned int) _styleMask;
+- (void) _setReleasedWhenClosed: (BOOL) flag;
+- (BOOL) _isReleasedWhenClosed;
 @end
 
 #endif
