@@ -23,9 +23,13 @@
 */
 #include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
-#include "GormPrivate.h"
+#include <InterfaceBuilder/IBPalette.h>
+#include <InterfaceBuilder/IBInspector.h>
+#include <InterfaceBuilder/IBApplicationAdditions.h>
+#include "GormDocument.h"
 #include "GormNSWindow.h"
 #include "GormNSPanel.h"
+#include "NSColorWell+GormExtensions.h"
 
 @interface GormWindowMaker : NSObject <NSCoding>
 {
@@ -201,7 +205,6 @@ NSwindow inspector
 }
 @end
 
-
 
 
 @interface GormWindowAttributesInspector : IBInspector
@@ -210,6 +213,9 @@ NSwindow inspector
   id backingMatrix;
   id optionMatrix;
   id controlMatrix;
+  id iconNameForm;
+  id clearButton;
+  id colorWell;
 }
 @end
 
@@ -217,11 +223,31 @@ NSwindow inspector
 
 - (void) _setValuesFromControl: control
 {
-
   if (control == titleForm)
     {
       [object setTitle: [[control cellAtIndex: 0] stringValue] ]; 
     }
+  else if (control == iconNameForm)
+    {
+      NSString *string = [[control cellAtIndex: 0] stringValue];
+      NSImage *image;
+
+      if ([string length] > 0)
+	{
+	  image = [NSImage imageNamed: string];
+	  [object setMiniwindowImage: image];
+	}
+      else
+	{
+	  // use the default, if the string is empty.
+	  [object setMiniwindowImage: nil];
+	}
+    }
+  else if (control == clearButton)
+    {
+      [[iconNameForm cellAtIndex: 0] setStringValue: nil];
+      [object setMiniwindowImage: nil];
+    }
   else if (control == backingMatrix)
     {
       [object setBackingType: [[control selectedCell] tag] ];
@@ -246,10 +272,15 @@ NSwindow inspector
       // (currently needs manual hide/unhide to update decorations)
       [object display];
    }
+  else if (control == colorWell)
+    {
+      [object setBackgroundColor: [colorWell color]];
+    }
   else if (control == optionMatrix)
     {
       BOOL flag;
-
+      GormDocument *doc = (GormDocument*)[(id<IB>)NSApp activeDocument];
+	
       // Release When Closed
       flag = ([[control cellAtRow: 0 column: 0] state] == NSOnState) ? YES : NO;
       [object _setReleasedWhenClosed: flag];
@@ -258,19 +289,13 @@ NSwindow inspector
       flag = ([[control cellAtRow: 1 column: 0] state] == NSOnState) ? YES : NO;
       [object setHidesOnDeactivate: flag];
 
-      // Visible at launch time. (not an object property. Stored in a Gorm dictionnary)
+      // Visible at launch time. (not an object property. Stored in a Gorm dictionary)
       flag = ([[control cellAtRow: 2 column: 0] state] == NSOnState) ? YES : NO;
-      {
-        GormDocument	*doc = (GormDocument*)[(id<IB>)NSApp activeDocument];
-        [doc setObject: object isVisibleAtLaunch: flag];
-      }
+      [doc setObject: object isVisibleAtLaunch: flag];
 
       // Deferred
       flag = ([[control cellAtRow: 3 column: 0] state] == NSOnState) ? YES : NO;
-      {
-        GormDocument	*doc = (GormDocument*)[(id<IB>)NSApp activeDocument];
-        [doc setObject: object isDeferred: flag];
-      }
+      [doc setObject: object isDeferred: flag];
 
       // One shot
       flag = ([[control cellAtRow: 4 column: 0] state] == NSOnState) ? YES : NO;
@@ -282,7 +307,7 @@ NSwindow inspector
 
       // wants to be color
       // FIXME:  probably means window depth > 2 bits per pixel but don't know
-      // exactly what NSWindow method to use to enforce  that.
+      // exactly what NSWindow method to use to enforce that.
       flag = ([[control cellAtRow: 6 column: 0] state] == NSOnState) ? YES : NO;
     }
 }
@@ -290,6 +315,7 @@ NSwindow inspector
 
 - (void) _getValuesFromObject: anObject
 {
+  GormDocument *doc = (GormDocument*)[(id<IB>)NSApp activeDocument];
   if (anObject != object)
     return;
 
@@ -313,22 +339,16 @@ NSwindow inspector
     [optionMatrix selectCellAtRow: 1 column: 0];
   
   // visible at launch time.
-  {
-    GormDocument *doc = (GormDocument*)[(id<IB>)NSApp activeDocument];
-    if ([doc objectIsVisibleAtLaunch: anObject])
-      {
-	[optionMatrix selectCellAtRow: 2 column: 0];
-      }
-  }
+  if ([doc objectIsVisibleAtLaunch: anObject])
+    {
+      [optionMatrix selectCellAtRow: 2 column: 0];
+    }
   
   // defer comes here.
-  {
-    GormDocument *doc = (GormDocument*)[(id<IB>)NSApp activeDocument];
-    if ([doc objectIsDeferred: anObject])
-      {
-	[optionMatrix selectCellAtRow: 3 column: 0];
-      }
-  }
+  if ([doc objectIsDeferred: anObject])
+    {
+      [optionMatrix selectCellAtRow: 3 column: 0];
+    }
 
   if ([anObject isOneShot])
     [optionMatrix selectCellAtRow: 4 column: 0];
@@ -337,7 +357,12 @@ NSwindow inspector
     [optionMatrix selectCellAtRow: 5 column: 0];
   
   // FIXME: wants to be color comes here
-  
+
+  // icon name
+  [[iconNameForm cellAtIndex: 0] setStringValue: [[object miniwindowImage] name]];
+
+  // background color
+  [colorWell setColorWithoutAction: [object backgroundColor]];
 }
 
 - (void) _validate: (id)anObject
@@ -371,7 +396,8 @@ NSwindow inspector
 
 - (void) ok: (id)sender
 {
-    [self _setValuesFromControl: sender];
+  [super ok: sender];
+  [self _setValuesFromControl: sender];
 }
 
 - (void) setObject: (id)anObject
@@ -467,6 +493,7 @@ NSwindow inspector
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sizeForm];
   [self _setValuesFromControl: minForm];
 }
