@@ -25,6 +25,7 @@
 #include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
 #include <InterfaceBuilder/InterfaceBuilder.h>
+#include "NSColorWell+GormExtensions.h"
 
 /* This macro makes sure that the string contains a value, even if @"" */
 #define VSTR(str) ({id _str = str; (_str) ? _str : @"";})
@@ -48,6 +49,8 @@
   id titleField;
   id horizontalSlider;
   id verticalSlider;
+  id colorWell;
+  id backgroundSwitch;
 }
 @end
 
@@ -77,10 +80,30 @@
       [object setContentViewMargins:
 	NSMakeSize([horizontalSlider floatValue], [control floatValue])];
     }
+  else if(control == colorWell)
+    {
+      NSTextFieldCell *titleCell = (NSTextFieldCell *)[object titleCell];
+      if([titleCell isKindOfClass: [NSTextFieldCell class]])
+	{
+	  [titleCell setBackgroundColor: [colorWell color]];
+	  [object display];
+	}
+    }
+  else if(control == backgroundSwitch)
+    {
+      NSTextFieldCell *titleCell = (NSTextFieldCell *)[object titleCell];
+      if([titleCell isKindOfClass: [NSTextFieldCell class]])
+	{
+	  BOOL state = ([backgroundSwitch state] == NSOnState)?YES:NO;
+	  [titleCell setDrawsBackground: state];
+	}
+    }
 }
 
 - (void) _getValuesFromObject: anObject
 {
+  NSTextFieldCell *titleCell = (NSTextFieldCell *)[anObject titleCell];
+  
   if (anObject != object)
     {
       return;
@@ -90,6 +113,12 @@
   [[titleField cellAtIndex: 0] setStringValue: VSTR([anObject title])];
   [horizontalSlider setFloatValue: [anObject contentViewMargins].width];
   [verticalSlider setFloatValue: [anObject contentViewMargins].height];
+  if([titleCell isKindOfClass: [NSTextFieldCell class]])
+    {
+      [colorWell setColorWithoutAction: [titleCell backgroundColor]];
+      [backgroundSwitch setState: ([titleCell drawsBackground]?
+				   NSOnState:NSOffState)];
+    }
 }
 
 - (id) init
@@ -100,7 +129,7 @@
     }
   if ([NSBundle loadNibNamed: @"GormNSBoxInspector" owner: self] == NO)
     {
-      NSLog(@"Could not gorm GormBoxInspector");
+      NSLog(@"Could not load GormBoxInspector");
       return nil;
     }
 
@@ -109,7 +138,7 @@
 
 - (void) ok: (id)sender
 {
-  NSDebugLog(@"ok: sender : %@", sender);
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -117,6 +146,17 @@
 {
   [super setObject: anObject];
   [self _getValuesFromObject: anObject];
+
+  if([[anObject titleCell] isKindOfClass: [NSTextFieldCell class]])
+    {
+      [colorWell setEnabled: YES];
+      [backgroundSwitch setEnabled: YES];
+    }
+  else
+    {
+      [colorWell setEnabled: NO];
+      [backgroundSwitch setEnabled: NO];
+    }
 }
 
 @end
@@ -126,6 +166,11 @@
  */
 @implementation	NSButton (IBObjectAdditions)
 
+- (NSString*) editorClassName
+{
+  return @"GormButtonEditor";
+}
+
 - (NSString*) inspectorClassName
 {
   return @"GormButtonAttributesInspector";
@@ -386,6 +431,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -505,6 +551,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -612,7 +659,7 @@
     {
       return;
     }
-  [backgroundColorWell setColor: [anObject backgroundColor]];
+  [backgroundColorWell setColorWithoutAction: [anObject backgroundColor]];
   [drawsBackgroundSwitch setState: 
     ([anObject drawsBackground]) ? NSOnState : NSOffState];
   [textMatrix selectCellWithTag: [[anObject  cellAtIndex: 0] alignment]];
@@ -668,6 +715,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   NSDebugLog(@"ok: sender is %@", sender);
   [self _setValuesFromControl: sender];
 }
@@ -799,7 +847,7 @@
       [autotagSwitch setEnabled: NO];
   }
 
-  [backgroundColorWell setColor: [anObject backgroundColor]];
+  [backgroundColorWell setColorWithoutAction: [anObject backgroundColor]];
   [drawsBackgroundSwitch setState: 
     ([anObject drawsBackground]) ? NSOnState : NSOffState];
 
@@ -827,6 +875,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -926,6 +975,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -1040,6 +1090,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -1161,6 +1212,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: valueField];
   [self _setValuesFromControl: minimumValueField];
   [self _setValuesFromControl: maximumValueField];
@@ -1287,8 +1339,8 @@
       return;
     } 
   [alignMatrix selectCellWithTag: [anObject alignment]];
-  [backgroundColor setColor: [anObject backgroundColor]];
-  [textColor setColor: [anObject textColor]];
+  [backgroundColor setColorWithoutAction: [anObject backgroundColor]];
+  [textColor setColorWithoutAction: [anObject textColor]];
   [drawsBackground setState: 
     ([anObject drawsBackground]) ? NSOnState : NSOffState];
   
@@ -1336,6 +1388,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -1492,7 +1545,7 @@
 {
   [disabled setState: (![object isEnabled])?NSOnState:NSOffState];
   [bordered setState: [object isBordered]?NSOnState:NSOffState];
-  [initialColor setColor: [object color]];
+  [initialColor setColorWithoutAction: [object color]];
   [tagValue setIntValue: [object tag]];
 }
 
@@ -1504,21 +1557,25 @@
 
 - (void) initialColorSelected: (id) sender
 {
+  [super ok: sender];
   [object setColor: [initialColor color]];
 }
 
 - (void) disabledSelected: (id)sender;
 {
+  [super ok: sender];
   [object setEnabled: ([disabled state] != NSOnState)];
 }
 
 - (void) borderedSelected: (id)sender;
 {
+  [super ok: sender];
   [object setBordered: ([bordered state] == NSOnState)];
 }
 
 - (void) tagSelected: (id)sender;
 {
+  [super ok: sender];
   [object setTag: [tagValue intValue]];
 }
 @end
