@@ -24,7 +24,9 @@
 #ifndef	INCLUDED_GormNSOutlineView_h
 #define	INCLUDED_GormNSOutlineView_h
 
-#include <AppKit/AppKit.h>
+#include <Foundation/Foundation.h>
+#include <AppKit/NSColor.h>
+#include <AppKit/NSOutlineView.h>
 
 @interface GormNSOutlineView : NSOutlineView
 {
@@ -35,12 +37,24 @@
   BOOL _gormAllowsColumnSelection;
   BOOL _gormAllowsMultipleSelection;
   BOOL _gormAllowsEmptySelection;
-  NSColor *_savedColor;
+  // NSColor *_savedColor;
 }
 
+- (void) setGormDelegate: (id)anObject;
+- (void) setGormAllowsColumnReordering: (BOOL)flag;
+- (BOOL) gormAllowsColumnReordering;
+- (void) setGormAllowsColumnResizing: (BOOL)flag;
+- (BOOL) gormAllowsColumnResizing;
+- (void) setGormAllowsMultipleSelection: (BOOL)flag;
+- (BOOL) gormAllowsMultipleSelection;
+- (void) setGormAllowsEmptySelection: (BOOL)flag;
+- (BOOL) gormAllowsEmptySelection;
+- (void) setGormAllowsColumnSelection: (BOOL)flag;
+- (BOOL) gormAllowsColumnSelection;
+
 // preserve the color during selection...
-- (void) select;
-- (void) unselect;
+//- (void) select;
+//- (void) unselect;
 @end
 
 #endif
