@@ -23,6 +23,7 @@
 */
 
 #include "GormNSOutlineView.h"
+#include <AppKit/NSTableColumn.h>
 
 /* --------------------------------------------------------------- 
  * NSTableView dataSource
@@ -191,7 +192,7 @@ static id _sharedDataSource = nil;
   self = [super initWithFrame: aRect];
   [super setDataSource: [GormNSOutlineView sharedDataSource]];
   _gormDataSource = nil;
-  ASSIGN(_savedColor,[NSColor controlBackgroundColor]);
+  // ASSIGN(_savedColor,[NSColor controlBackgroundColor]);
   return self;
 }
 
@@ -259,14 +260,14 @@ static id _sharedDataSource = nil;
   _gormAllowsEmptySelection = _allowsEmptySelection;
   _gormDelegate = _delegate;
   _delegate = nil;
-  ASSIGN(_savedColor, [self backgroundColor]);
+  // ASSIGN(_savedColor, [self backgroundColor]);
 
   return self;
 }
 
 - (void) dealloc
 {
-  RELEASE(_savedColor);
+  // RELEASE(_savedColor);
   [super dealloc];
 }
 
@@ -325,6 +326,7 @@ static id _sharedDataSource = nil;
   return @"NSOutlineView";
 }
 
+/*
 - (void) setBackgroundColor: (NSColor *)color
 {
   [super setBackgroundColor: color];
@@ -341,4 +343,5 @@ static id _sharedDataSource = nil;
   [super setBackgroundColor: _savedColor]; 
   [self deselectAll: self];
 }
+*/
 @end
