@@ -24,10 +24,12 @@
 */
 
 #include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
-#include <InterfaceBuilder/InterfaceBuilder.h>
+#include <AppKit/NSTableColumn.h>
+#include <AppKit/NSBrowser.h>
+#include <InterfaceBuilder/IBInspector.h>
 #include "GormNSTableView.h"
 #include "GormPrivate.h"
+#include "NSColorWell+GormExtensions.h"
 
 /* This macro makes sure that the string contains a value, even if @"" */
 #define VSTR(str) ({id _str = str; (_str) ? _str : @"";})
@@ -76,9 +78,9 @@
       [object setTitled: flag];
 
       flag = ([[control cellAtRow: 5 column: 0] state] == NSOnState) ? YES : NO;
-      [object setHasHorizontalScroller: flag];
+      [object setHasHorizontalScroller: flag]; 
     }
-  else if( control == tagField )
+  else if(control == tagField)
     {
       [object setTag:[[tagField cellAtIndex:0] intValue]];
     }
@@ -127,6 +129,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -217,6 +220,7 @@
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -288,7 +292,7 @@
       break;
     }
 
-  [identifierTextField setStringValue: [anObject identifier]];
+  [identifierTextField setStringValue: [(NSTableColumn *)anObject identifier]];
 
   if ([anObject isResizable])
     [resizableSwitch setState: NSOnState];
@@ -392,7 +396,7 @@
 	  [doc attachObject: cell toParent: object];
 	  if((name = [doc nameForObject: cell]) != nil)
 	    {
-	      [classManager setCustomClass: className forObject: name];
+	      [classManager setCustomClass: className forName: name];
 	    } 
 	}
 
@@ -468,6 +472,7 @@ shouldEditTableColumn: (NSTableColumn *)aTableColumn
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -589,7 +594,7 @@ shouldEditTableColumn: (NSTableColumn *)aTableColumn
 	      for(i = 0; i < colsToAdd; i++)
 		{
 		  NSString *identifier = [NSString stringWithFormat: @"column%d",(numCols + i + 1)];
-		  NSTableColumn *tc = AUTORELEASE([[NSTableColumn alloc] initWithIdentifier: identifier]);
+		  NSTableColumn *tc = AUTORELEASE([(NSTableColumn *)[NSTableColumn alloc] initWithIdentifier: (id)identifier]);
 		  [tc setWidth: 50];
 		  [tc setMinWidth: 20];
 		  [tc setResizable: YES];
@@ -691,7 +696,7 @@ shouldEditTableColumn: (NSTableColumn *)aTableColumn
   [[tagField cellAtIndex:0] setIntValue:[anObject tag]];
 
   // set the background color into the inspector...
-  [backgroundColor setColor: [anObject backgroundColor]];
+  [backgroundColor setColorWithoutAction: [anObject backgroundColor]];
 }
 
 - (id) init
@@ -712,6 +717,7 @@ shouldEditTableColumn: (NSTableColumn *)aTableColumn
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -736,6 +742,11 @@ static NSString *ITEM=@"item";
   return @"GormTabViewInspector";
 }
 
+- (NSString*) editorClassName
+{
+  return @"GormTabViewEditor";
+}
+
 @end
 
 @interface GormTabViewInspector : IBInspector
@@ -793,7 +804,7 @@ static NSString *ITEM=@"item";
 	  for (i=([object numberOfTabViewItems]+1);i<=newNumber;i++)
 	    {
 	      NSString *identif = [NSString stringWithFormat:@"%i",i]; 
-	      newTabItem = [[NSTabViewItem alloc] initWithIdentifier:identif];
+	      newTabItem = [(NSTabViewItem *)[NSTabViewItem alloc] initWithIdentifier: (id)identif];
 	      [newTabItem setLabel:[ITEM  stringByAppendingString:identif]]; 
 	      [newTabItem setView:[[NSView alloc] init]];
 	      [object addTabViewItem:newTabItem];
@@ -855,6 +866,7 @@ static NSString *ITEM=@"item";
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
