@@ -26,6 +26,7 @@
 #include <AppKit/AppKit.h>
 #include "GormPrivate.h"
 #include "GormViewEditor.h"
+#include "NSColorWell+GormExtensions.h"
 
 /* This macro makes sure that the string contains a value, even if @"" */
 #define VSTR(str) ({id _str = str; (_str) ? _str : @"";})
@@ -122,8 +123,8 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
   if (anObject != object)
     return;
 
-  [backgroundColorWell setColor: [anObject backgroundColor]];
-  [textColorWell setColor: [anObject textColor]];
+  [backgroundColorWell setColorWithoutAction: [anObject backgroundColor]];
+  [textColorWell setColorWithoutAction: [anObject textColor]];
     
   [alignmentMatrix selectCellWithTag: [anObject alignment]];
 
@@ -159,6 +160,7 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -322,6 +324,7 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -537,8 +540,8 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
   scrollView = [[anObject superview] superview];
   isScrollView = [ scrollView isKindOfClass: [NSScrollView class]];
 
-  [backgroundColorWell setColor: [anObject backgroundColor]];
-  [textColorWell setColor: [anObject textColor]];
+  [backgroundColorWell setColorWithoutAction: [anObject backgroundColor]];
+  [textColorWell setColorWithoutAction: [anObject textColor]];
 
   if (isScrollView) {
     [borderMatrix selectCellWithTag: [scrollView borderType]];
@@ -572,6 +575,7 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -619,9 +623,7 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
   if (control == detachButton)
     {
       [[object cell] setFormatter: nil];
-      // FIXME: Should empty the inspector window or show
-      // the default inspector. How do we do that?
-      //[ (GormInspectorManager *)[window view] setCurrentInspector: 0] ??
+      [[(Gorm *)NSApp activeDocument] setSelectionFromEditor: nil];
     }
   else
     {
@@ -711,54 +713,13 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
       return nil;
     }
 
-  // Add format/date table view by hand for now...
-  {
-    NSScrollView *v;
-    NSTableColumn  *tc;
-    NSSize contentSize;
-
-    v = [[NSScrollView alloc] initWithFrame: NSMakeRect(5,170,IVW-10,200)];
-    [v setHasVerticalScroller: YES];
-    [v setHasHorizontalScroller: NO];
-    contentSize = [v contentSize];
-
-    formatTable = [[NSTableView alloc] initWithFrame:
-             NSMakeRect(0,0,contentSize.width, contentSize.height)];
-    
-    [formatTable setDataSource: self];
-    [formatTable setDelegate: self];
-    [formatTable setAutoresizesAllColumnsToFit: YES];
-    [formatTable setAllowsEmptySelection: YES];
-    [formatTable setAllowsMultipleSelection: NO];
-    [v setDocumentView: formatTable];
-
-    tc = [[NSTableColumn alloc] initWithIdentifier: @"format"];
-    [[tc headerCell] setStringValue: @"Format"];
-    [tc setWidth: contentSize.width*4/9];
-    [tc setResizable: NO];
-    [tc setEditable: NO];
-    [formatTable addTableColumn: tc];
-    RELEASE(tc);
-    
-    tc = [[NSTableColumn alloc] initWithIdentifier: @"date"];
-    [[tc headerCell] setStringValue: @"Date"];
-    [tc setMinWidth: contentSize.width*5/9];
-    [tc setResizable: NO];
-    [tc setEditable: NO];
-    [formatTable addTableColumn: tc];
-    RELEASE(tc);
-  
-    [v setDocumentView: formatTable];
-    [[window contentView] addSubview: v];
-    RELEASE(v);
-  }
-
   return self;
 }
 
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
@@ -863,9 +824,7 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
   if (control == detachButton)
     { 
       [cell setFormatter: nil];
-      // FIXME: Should empty the inspector window or show
-      // the default inspector. How do we do that?
-      //[ (GormInspectorManager *)[window view] setCurrentInspector: 0] ??
+      [[(Gorm *)NSApp activeDocument] setSelectionFromEditor: nil];
     }
   else
     {
@@ -1020,47 +979,6 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
       return nil;
     }
 
-  // Add positive/negative format table view by hand for now...
-  {
-    NSScrollView *v;
-    NSTableColumn  *tc;
-    NSSize contentSize;
-
-    v = [[NSScrollView alloc] initWithFrame: NSMakeRect(12,268,245,118)];
-    [v setHasVerticalScroller: YES];
-    [v setHasHorizontalScroller: NO];
-    contentSize = [v contentSize];
-
-    formatTable = [[NSTableView alloc] initWithFrame:
-             NSMakeRect(0,0,contentSize.width, contentSize.height)];
-    
-    [formatTable setDataSource: self];
-    [formatTable setDelegate: self];
-    [formatTable setAutoresizesAllColumnsToFit: YES];
-    [formatTable setAllowsEmptySelection: YES];
-    [formatTable setAllowsMultipleSelection: NO];
-
-    tc = [[NSTableColumn alloc] initWithIdentifier: @"positive"];
-    [[tc headerCell] setStringValue: @"Positive"];
-    [tc setWidth: contentSize.width/2];
-    [tc setResizable: NO];
-    [tc setEditable: NO];
-    [formatTable addTableColumn: tc];
-    RELEASE(tc);
-    
-    tc = [[NSTableColumn alloc] initWithIdentifier: @"negative"];
-    [[tc headerCell] setStringValue: @"Negative"];
-    [tc setMinWidth: contentSize.width/2];
-    [tc setResizable: NO];
-    [tc setEditable: NO];
-    [formatTable addTableColumn: tc];
-    RELEASE(tc);
-  
-    [v setDocumentView: formatTable];
-    [[window contentView] addSubview: v];
-    RELEASE(v);
-  }
-
   // Initialize Positive/Negative appearance fields formatter
   {
     NSNumberFormatter *fmtr = [[NSNumberFormatter alloc] init];
@@ -1077,6 +995,7 @@ extern NSArray *predefinedDateFormats, *predefinedNumberFormats;
 
 - (void) ok: (id)sender
 {
+  [super ok: sender];
   [self _setValuesFromControl: sender];
 }
 
